@@ -8,25 +8,11 @@
 
 
 args <- commandArgs(TRUE)
+
 optionsFile <- args[1]
-print(optionsFile)
 
-#--- user commands ---
-getOptionsFromFile <- function(optionsFile, lines) {
-	optionsCon <- file(optionsFile, 'r')
-	options=readLines(optionsCon, n=lines)
-	close(optionsCon)
-	return (options)
-}
+options <- scan(optionsFile, comment.char="#", what=character(), sep="\n")
 
-#way A. passing options to a file
-options <- getOptionsFromFile(optionsFile, 32)
-
-#way B. put options as arguments
-#unused because maybe command line gets too long
-#options <- commandArgs(TRUE)
-
-#print(options)
 
 #---------------------------------------------------------------------
 #			Attention
@@ -41,6 +27,12 @@ EncoderConfigurationName <- ""
 English = unlist(strsplit(options[30], "\\;"))
 Translated = unlist(strsplit(options[31], "\\;"))
 
+#TODO: now that there's a start and continue of each process from R,
+#instead of pass and script from R,
+#pass the directory
+#and R will source() the needed files (maybe all the first time)
+#and it will not do again when the process is continued (see encoderRProc.cs)
+
 scriptUtilR = options[28]
 source(scriptUtilR)
 
@@ -70,5 +62,19 @@ loadLibraries(OperatingSystem)
 print("Creating (OutputData2)3.txt with touch method...")
 file.create(paste(OutputData2,"3.txt",sep=""))
 print("Created")
+	
+#open stdin connection
+f <- file("stdin")
+open(f)
 
-doProcess(options)
+
+while(TRUE) {
+	doProcess(options)
+
+	input <- readLines(f, n = 1L)
+	if(input[1] == "Q")
+		quit("no")
+			
+	write("received a continue signal", stderr())
+	options <- scan(optionsFile, comment.char="#", what=character(), sep="\n")
+}
