@@ -146,8 +146,260 @@ translateVector <- function(englishVector) {
 #	return(displacement)
 #}
 
+#this is equal to runEncoderCaptureCsharp()
+#but note getDisplacement hapens before this function, so no need getDisplacement here
+#also don't need byteReadedRaw, and encoderReadedRaw. encoderReaded is 'displacement' here
+findCurvesNew <- function(displacement, eccon, isInertial, min_height, draw, title) 
+{
+	#---- 1) declare variables ----
+	
+	byteReaded = NULL
+					
+	position = cumsum(displacement)
 
-findCurves <- function(displacement, eccon, min_height, draw, title) {
+	sum = 0
+
+	directionChangePeriod = 25
+	directionChangeCount = 0
+	directionNow = 1
+	directionLastMSecond = 1
+	directionCompleted = -1
+	previousFrameChange = 0
+	previousEnd = 1
+	lastNonZero = 0
+
+	heightAtCurveStart = 0
+	heightAccumulated = 0
+
+	inertialCaptureDirectionChecked = FALSE
+	inertialCaptureDirectionInverted = FALSE
+		
+	capturingFirstPhase = TRUE
+
+	startCurrent = NULL
+	endCurrent = NULL
+
+	startStored = 0
+	endStored= 0
+	startHStored = 0
+
+	#curve we are about to store is concentric
+	directionToStoreIsCon = NULL #bool
+	#last stored curve is concentric. It's important on 'ec' to store first 'e', next 'c' ...
+	directionStoredIsCon = NULL #bool
+		
+	#               3
+	#              / \
+	#             /   B
+	#            /     \
+	# --1       /
+	#    \     /
+	#     \   A
+	#      \2/
+	#
+	# At B, we evaluate if 2-3 curve is concentric.
+	# directionToStoreIsCon == TRUE
+
+
+	#               3               5
+	#              / \             /
+	#             /   B           /
+	#            /     \         /
+	# --1       /       \       /
+	#    \     /         \     /
+	#     \   A           \   C
+	#      \2/             \4/
+	#
+	# At C, we evaluate if 3-4 curve is eccentric.
+	# directionToStoreIsCon == FALSE
+	# Also we see that last stored curve is opposite:
+	# directionStoredIsCon == TRUE
+	#
+
+
+	row = 1
+
+	count = 1
+
+	#---- 2) start ----
+
+	while(count <= length(displacement)) {
+
+	      byteReaded = displacement[count]
+
+	      #TODO: need this?	
+	      #if(inertialCaptureDirectionInverted)
+	      #	byteReadedRaw = -1 * byteReadedRaw
+
+	      sum = sum + byteReaded
+
+	      #the inertial change of direction is not needed here because runEncoderCaptureCsharp() stores data already 'changed'
+	      #so no change here is needed
+
+	      #if string goes up or down, store the direction
+	      if(byteReaded != 0)
+		      directionNow = byteReaded / ( 1.0 * abs(byteReaded) ) #1 (up) or -1 (down)
+
+	      #if we don't have changed the direction, store the last non-zero that we can find
+	      if(directionChangeCount == 0 && directionNow == directionLastMSecond) {
+		      if(byteReaded != 0)
+			      lastNonZero = count
+	      }
+
+	      #if it's different than the last direction, mark the start of change
+	      if(directionNow != directionLastMSecond) {
+		      directionLastMSecond = directionNow
+		      directionChangeCount = 0
+	      } 
+	      else if(directionNow != directionCompleted) {
+		      #we are in a different direction than the last completed
+
+		      directionChangeCount = directionChangeCount +1
+
+		      if(directionChangeCount > directionChangePeriod)
+		      {
+			      startFrame = previousEnd
+			      if(startFrame < 1)
+				      startFrame = 1
+
+			      startCurrent = startFrame
+			      #-1 are because on C# count starts at 0 and here count starts at 1
+			      endCurrent = ( (count -1) - directionChangeCount + (lastNonZero -1) ) / 2
+
+			      if(endCurrent > startCurrent)
+			      {
+				      heightAtCurveStart = heightAccumulated
+
+				      heightCurve = max(position[startCurrent:endCurrent]) - min(position[startCurrent:endCurrent])
+
+				      previousEnd = endCurrent
+
+				      heightAccumulated = heightAccumulated + heightCurve
+
+				      heightCurve = abs(heightCurve) #mm -> cm
+			      
+				      sendCurve = TRUE
+
+				      if(heightCurve >= min_height) {
+					      #TODO: add the inertia stuff here?
+					      
+					      directionToStoreIsCon = ( position[endCurrent] > position[startCurrent] )
+
+					      if( eccon == "c" && ! directionToStoreIsCon )
+						      sendCurve = FALSE
+					      if( (eccon == "ec" || eccon == "ecS") && directionToStoreIsCon && capturingFirstPhase )
+						      sendCurve = FALSE
+					      
+					      #on ec, ecS don't have store two curves in the same direction
+					      if( (eccon == "ec" || eccon == "ecS") && 
+						 ! is.null(directionStoredIsCon) && 
+						 directionToStoreIsCon == directionStoredIsCon )
+						      sendCurve = FALSE
+
+					      capturingFirstPhase = FALSE
+				      } else {
+					      sendCurve = FALSE
+				      }
+
+				      #store the curve
+				      if(sendCurve) {
+					      startStored[row] = startCurrent
+					      endStored[row] = endCurrent
+					      startHStored[row] = position[startCurrent]
+					      row = row + 1
+					      directionStoredIsCon = directionToStoreIsCon
+				      }
+			      }
+
+			      previousFrameChange = count - directionChangeCount
+			      directionChangeCount = 0
+			      directionCompleted = directionNow
+		      }
+	      }
+
+	      count = count +1
+	}
+	
+	#if eccon it's 'ec' and last row it's 'e', delete it
+	if(row > 1)
+	{
+		startStoredLast = startStored[length(startStored)]
+		endStoredLast = endStored[length(endStored)]
+
+		#write("startStoredLast, endStoredLast", stderr())
+		#write(c(startStoredLast, endStoredLast), stderr())
+	
+		if ( position[startStoredLast] > position[endStoredLast] ) 
+		{
+			write("deleting last ecc row", stderr())
+			startStored = startStored[-length(startStored)]
+			endStored = endStored[-length(endStored)]
+			startHStored = startHStored[-length(startHStored)]
+		}
+	}
+
+	#if eccon == "ec" mix 'e' and 'c' curves
+	if(eccon == "ec") {
+		startStoredOld = startStored
+		endStoredOld = endStored
+		startHStoredOld = startHStored
+
+		startStored = NULL
+		endStored = NULL
+		startHStored = NULL
+
+		n=length(startStoredOld)
+		count = 1
+		for(i in seq(1, n, by=2)) {
+			startStored[count] = startStoredOld[i]
+			endStored[count] = endStoredOld[(i+1)]
+			startHStored[count] = startHStoredOld[i]
+			count = count +1
+		}
+
+		#be careful on ec inertial to send an startStored of 1220.5 because can use the 1220 that can be a positive displacement
+		#and then the 1221 can be negative and also the rest
+		#then is better to take the second number (do ceiling) to avoid a change of direction on the beginning of the movement
+		#
+		#    AB          C
+		#    /\          /\
+		#   /  \        /
+		#  /    \      /
+		# /      \    /
+		#         \__/
+		#
+		# On this example a ec can go from B to C. If it uses A,
+		#then there will be a change of direction that will make getSpeed to produce a mistaken spline
+
+		if(isInertial) {
+			for(i in 1:length(startStored)) {
+				startStored[i] = ceiling(startStored[i])
+			}
+		}
+	}
+
+	if(draw) {
+		lty=1
+		col="black"
+		plot((1:length(position))/1000			#ms -> s
+		     ,position/10,				#mm -> cm
+		     type="l",
+		     xlim=c(1,length(position))/1000,		#ms -> s
+		     xlab="",ylab="",axes=T,
+		     lty=lty,col=col) 
+
+		title(title, cex.main=1, font.main=1)
+		mtext(paste(translate("time"),"(s)"),side=1,adj=1,line=-1)
+		mtext(paste(translate("displacement"),"(cm)"),side=2,adj=1,line=-1)
+	}
+	
+	return(as.data.frame(cbind(startStored,endStored,startHStored)))
+}
+
+#extrema method
+#there are problems when small changes of direction are found
+#unused now, use the new findCurves (above) that is equal to runEncoderCaptureCsharp()
+findCurvesOld <- function(displacement, eccon, min_height, draw, title) {
 	position=cumsum(displacement)
 	position.ext=extrema(position)
 	print("at findCurves")
@@ -156,13 +408,22 @@ findCurves <- function(displacement, eccon, min_height, draw, title) {
 	start=0; end=0; startH=0
 	tempStart=0; tempEnd=0;
 	#TODO: fer algo per si no es detecta el minindex previ al salt
-	if(eccon=="c") {
+	if(eccon=="c") 
+	{
+		#1) fix big problems with set (signal). No minindex or no maxindex
 		if(length(position.ext$minindex)==0) { position.ext$minindex=cbind(1,1) }
 		if(length(position.ext$maxindex)==0) { position.ext$maxindex=cbind(length(position),length(position)) }
-		#fixes if 1st minindex is after 1st maxindex
+
+		#2) fixes if 1st minindex is after 1st maxindex
 		if(position.ext$maxindex[1] < position.ext$minindex[1]) { position.ext$minindex = rbind(c(1,1),position.ext$minindex) } 
-		row=1; i=1; j=1
-		while(max(c(i,j)) <= min(c(length(position.ext$minindex[,1]),length(position.ext$maxindex[,1])))) {
+		
+		#3 find the curves (enter the bucle)
+
+		row=1; #row means each curve
+		i=1; j=1 #i minimums; j maximums
+		while(max(c(i,j)) <= min(c(length(position.ext$minindex[,1]),length(position.ext$maxindex[,1])))) 
+		{
+			#3.1) assign tempStart and tempEnd using extrema data
 
 			#tempStart at the end of minindexs
 			#tempStart = position.ext$minindex[i,2]
@@ -179,6 +440,8 @@ findCurves <- function(displacement, eccon, min_height, draw, title) {
 			#end at the first maximum value
 			#tempEnd = position.ext$maxindex[j,1]
 
+			#3.2) get heigh. Store curve if it's enough
+
 			height=position[tempEnd]-position[tempStart]
 			if(height >= min_height) { 
 				start[row] = tempStart
@@ -188,7 +451,7 @@ findCurves <- function(displacement, eccon, min_height, draw, title) {
 				#if(eccon=="c") { break } #c only needs one result
 			} 
 			i=i+1; j=j+1
-		}
+		} #end of while
 	} else { #ec, ecS, ce, ceS
 		row=1; i=1; j=2
 
@@ -281,14 +544,23 @@ findCurves <- function(displacement, eccon, min_height, draw, title) {
 	return(as.data.frame(cbind(start,end,startH)))
 }
 
-
-
+findSmoothingsECGetPower <- function(speed)
+{
+	acceleration <- getAcceleration(speed)
+	acceleration$y <- acceleration$y * 1000
+	force <- 50 * (acceleration$y + 9.81) #Do always with 50Kg right now. TODO: See if there's a need of real mass value
+	power <- force * speed$y
+	return(power)
+}
 #called on "ec" and "ce" to have a smoothingOneEC for every curve
 #this smoothingOneEC has produce same speeds than smoothing "c"
-findSmoothingsEC <- function(singleFile, displacement, curves, eccon, smoothingOneC) {
+findSmoothingsEC <- function(singleFile, displacement, curves, eccon, smoothingOneC) 
+{
+	#print(c("findSmoothingsEC: eccon smoothingOneC", eccon, smoothingOneC))
+
 	smoothings = NULL
 	n=length(curves[,1])
-	
+
 	#if not "ec" or "ce" just have a value of 0 every curve,
 	#no problem, this value will not be used
 	#is just to not make crash other parts of the software like reduceCurveBySpeed
@@ -322,31 +594,44 @@ findSmoothingsEC <- function(singleFile, displacement, curves, eccon, smoothingO
 					start = 0
 					end = mean(which(position == max(position)))
 				}
-				print("start, end")
-				print(c(start, end))
+				#print("start, end")
+				#print(c(start, end))
 
 				concentric=displacement[(curves[i,1]+start):(curves[i,1]+end)]
-
+				
 				#get max speed at "c"
-				print("calling speed 1")
-				print("unique(concentric)")
-				print(unique(concentric))
-				print("concentric")
-				print(concentric)
+				#print("calling speed 1")
+				#print("unique(concentric)")
+				#print(unique(concentric))
+				#print("concentric")
+				#print(concentric)
+				
 				speed <- getSpeed(concentric, smoothingOneC)
-				print("called")
-				maxSpeedC=max(speed$y)
+				#maxSpeedC=max(speed$y)
+				
+				powerC <- findSmoothingsECGetPower(speed)
+				maxPowerC <- max(powerC) 
 
 				#find max speed at "ec" that's similar to maxSpeedC
 				smoothingOneEC = smoothingOneC
-				for(j in seq(as.numeric(smoothingOneC),0,by=-.01)) {
-					print("calling speed 2")
+				for(j in seq(as.numeric(smoothingOneC),0,by=-.01)) 
+				{
+					#write("calling speed 2", stderr())
 					speed <- getSpeed(eccentric.concentric, j)
-					print("called")
+					
 					smoothingOneEC = j
-					maxSpeedEC=max(speed$y)
-					print(c("j",j,"maxC",round(maxSpeedC,3),"maxEC",round(maxSpeedEC,3)))
-					if(maxSpeedEC >= maxSpeedC)
+					
+					#don't do it base on speed because difference is very tiny
+					#do it based on power
+					#maxSpeedEC=max(speed$y)
+					#write(c("j",j,"maxC",round(maxSpeedC,3),"maxEC",round(maxSpeedEC,3)),stderr())
+					#if(maxSpeedEC >= maxSpeedC)
+					#	break
+
+					powerEC <- findSmoothingsECGetPower(speed)
+					maxPowerEC <- max(powerEC) 
+					
+					if(maxPowerEC >= maxPowerC)
 						break
 				}
 
@@ -424,6 +709,14 @@ kinematicRanges <- function(singleFile, displacement, curves,
 		power=c(-maxPower,maxPower)))
 }
 
+canJump <- function(encoderConfigurationName)
+{
+  if(encoderConfigurationName == "LINEAR" || encoderConfigurationName == "LINEARINVERTED")
+    return(TRUE)
+  
+  return(FALSE)
+}
+  
 
 paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose, highlight,
 	startX, startH, smoothingOneEC, smoothingOneC, massBody, massExtra, 
@@ -444,6 +737,7 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 	else
 		smoothing = smoothingOneEC
 
+	write(c("paint smoothing", smoothing), stderr())
 
 	#eccons ec and ecS is the same here (only show one curve)
 	#receive data as cumulative sum
@@ -519,9 +813,10 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 
 	#speed
 	speed <- getSpeed(displacement, smoothing)
-       	
+
 	if(draw & showSpeed) {
-		ylim=c(-max(abs(range(displacement))),max(abs(range(displacement))))	#put 0 in the middle 
+		ylimHeight = max(abs(range(speed$y)))
+		ylim=c(- 1.05 * ylimHeight, 1.05 * ylimHeight)	#put 0 in the middle, and have 5% margin at each side
 		if(knRanges[1] != "undefined")
 			ylim = knRanges$speedy
 		par(new=T)
@@ -545,8 +840,18 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 		abline(v=maxSpeedT, col=cols[1])
 		points(maxSpeedT, max(speed$y),col=cols[1])
 		mtext(text=paste(round(max(speed$y),2),"m/s",sep=""),side=3,
-		      at=maxSpeedT,cex=.8,col=cols[1], line=.2)
+		      at=maxSpeedT,cex=.8,col=cols[1], line=.5)
 		mtext(text=maxSpeedT,side=1,at=maxSpeedT,cex=.8,col=cols[1],line=-.2)
+
+		if(eccon != "c") {
+			minSpeedT=min(which(speed$y == min(speed$y)))
+			
+			abline(v=minSpeedT, col=cols[1])
+			points(minSpeedT, min(speed$y),col=cols[1])
+			mtext(text=paste(round(min(speed$y),2),"m/s",sep=""),side=3,
+			      at=minSpeedT,cex=.8,col=cols[1], line=.5)
+			mtext(text=minSpeedT,side=1,at=minSpeedT,cex=.8,col=cols[1],line=-.2)
+		}
 	}
 
 
@@ -619,8 +924,12 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 			      side=1,at=min(isometric),adj=1,cex=.8,col=cols[1])
 			mtext(text=paste(" ", round(max(isometric),1),sep=""), 
 			      side=1,at=max(isometric),adj=0,cex=.8,col=cols[1])
-			mtext(text=paste(translate("eccentric")," ",sep=""),side=3,at=max(eccentric),cex=.8,adj=1,col=cols[1],line=.5)
-			mtext(text=paste(" ",translate("concentric"),sep=""),side=3,at=min(concentric),cex=.8,adj=0,col=cols[1],line=.5)
+
+			#don't need to show eccentric and concentric. It's pretty clear
+			#mtext(text=paste(translate("eccentric")," ",sep=""),side=3,at=max(eccentric),cex=.8,adj=1,col=cols[1],line=.5)
+			#mtext(text=paste(" ",translate("concentric"),sep=""),side=3,at=min(concentric),cex=.8,adj=0,col=cols[1],line=.5)
+			mtext(text="ecc ",side=3,at=max(eccentric),cex=.8,adj=1,col=cols[1],line=.5)
+			mtext(text=" con",side=3,at=min(concentric),cex=.8,adj=0,col=cols[1],line=.5)
 		}
 	}
 	
@@ -656,6 +965,18 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 
 	print(c("propulsiveEnd at paint", propulsiveEnd))
 
+	#on inertial ec. If the accel starts as negative, calcule avg values and peak values starting when the accel is positive
+	#because the acceleration done on the disc can only be positive
+	inertialECstart = 1
+	if(length(eccentric) > 0)
+		inertialECstart = min(eccentric)
+
+	if(inertiaMomentum > 0 && eccon == "ec" && accel$y[1] < 0) {
+		inertialECstart <- min(which(accel$y > 0))
+		abline(v=inertialECstart,lty=3,col="black") 
+	}
+
+
 	meanSpeedC = mean(speed$y[min(concentric):max(concentric)])
 	if(isPropulsive) {
 		meanSpeedC = mean(speed$y[min(concentric):propulsiveEnd])
@@ -666,22 +987,25 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 			arrows(x0=min(concentric),y0=meanSpeedC,x1=propulsiveEnd,y1=meanSpeedC,col=cols[1],code=3)
 		}
 	} else {
-		meanSpeedE = mean(speed$y[min(eccentric):max(eccentric)])
+		meanSpeedE = mean(speed$y[inertialECstart:max(eccentric)])
 		if(showSpeed) {
-			arrows(x0=min(eccentric),y0=meanSpeedE,x1=max(eccentric),y1=meanSpeedE,col=cols[1],code=3)
+			arrows(x0=inertialECstart,y0=meanSpeedE,x1=max(eccentric),y1=meanSpeedE,col=cols[1],code=3)
 			arrows(x0=min(concentric),y0=meanSpeedC,x1=propulsiveEnd,y1=meanSpeedC,col=cols[1],code=3)
 		}
 	}
 
 	if(draw) {
-		ylim=c(-max(abs(range(accel$y))),max(abs(range(accel$y))))	 #put 0 in the middle
+		ylimHeight = max(abs(range(accel$y)))
+		ylim=c(- 1.05 * ylimHeight, 1.05 * ylimHeight)	#put 0 in the middle, and have 5% margin at each side
 		if(knRanges[1] != "undefined")
 			ylim = knRanges$accely
 
 		
+		#always (single or side) show 0 line
+		abline(h=0,lty=3,col="black")
+		
 		#plot the speed axis
 		if(showAxes & showSpeed) {
-			abline(h=0,lty=3,col="black")
 			if(eccon == "c") {
 				axis(4, at=c(min(axTicks(4)),0,max(axTicks(4)),meanSpeedC),
 				     labels=c(min(axTicks(4)),0,max(axTicks(4)),
@@ -733,14 +1057,15 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 
 	dynamics = getDynamics(encoderConfigurationName,
 			speed$y, accel$y, massBody, massExtra, exercisePercentBodyWeight, gearedDown, anglePush, angleWeight,
-			displacement, diameter, diameterExt, inertiaMomentum, smoothing)
+			displacement, diameter, inertiaMomentum, smoothing)
 	mass = dynamics$mass
 	force = dynamics$force
 	power = dynamics$power
 
 
 	if(draw & showForce) {
-		ylim=c(-max(abs(range(force))),max(abs(range(force))))	 #put 0 in the middle
+		ylimHeight = max(abs(range(force)))
+		ylim=c(- 1.05 * ylimHeight, 1.05 * ylimHeight)	#put 0 in the middle, and have 5% margin at each side
 		if(knRanges[1] != "undefined")
 			ylim = knRanges$force
 		par(new=T)
@@ -782,12 +1107,12 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 		#takeoff = min(which(force[concentric]<=weight)) + length_eccentric + length_isometric
 
 		takeoff = -1
-		if(length(which(force[concentric] <= 0)) == 0)
+		if(! canJump(encoderConfigurationName) || length(which(force[concentric] <= 0)) == 0)
 			takeoff = -1
 		else {
 			#1 get force only in concentric phase
 			forceConcentric = force[concentric]
-			print(c("forceConcentric",forceConcentric))
+			#print(c("forceConcentric",forceConcentric))
 
 			#2 get takeoff using maxSpeedT but relative to concentric, not all the ecc-con
 			
@@ -829,7 +1154,8 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 
 
 	if(draw & showPower) {
-		ylim=c(-max(abs(range(power))),max(abs(range(power))))	#put 0 in the middle
+		ylimHeight = max(abs(range(power)))
+		ylim=c(- 1.05 * ylimHeight, 1.05 * ylimHeight)	#put 0 in the middle, and have 5% margin at each side
 		if(knRanges[1] != "undefined")
 			ylim = knRanges$power
 		par(new=T);
@@ -849,8 +1175,8 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 		if(eccon == "c") {
 			arrows(x0=min(concentric),y0=meanPowerC,x1=propulsiveEnd,y1=meanPowerC,col=cols[3],code=3)
 		} else {
-			meanPowerE = mean(power[min(eccentric):max(eccentric)])
-			arrows(x0=min(eccentric),y0=meanPowerE,x1=max(eccentric),y1=meanPowerE,col=cols[3],code=3)
+			meanPowerE = mean(power[inertialECstart:max(eccentric)])
+			arrows(x0=inertialECstart,y0=meanPowerE,x1=max(eccentric),y1=meanPowerE,col=cols[3],code=3)
 			arrows(x0=min(concentric),y0=meanPowerC,x1=propulsiveEnd,y1=meanPowerC,col=cols[3],code=3)
 		}
 
@@ -877,15 +1203,29 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 			axisLineRight = axisLineRight +2
 		}
 	}
-
+	
 	#time to arrive to peak power
-	peakPowerT=min(which(power == max(power)))
+	powerTemp <- power[inertialECstart:length(power)]
+	peakPowerT <- min(which(power == max(powerTemp)))
 	if(draw & !superpose & showPower) {
 		abline(v=peakPowerT, col=cols[3])
-		points(peakPowerT, max(power),col=cols[3])
-		mtext(text=paste(round(max(power),1),"W",sep=""),side=3,at=peakPowerT,adj=0.5,cex=.8,col=cols[3],line=-.2)
+		points(peakPowerT, max(powerTemp),col=cols[3])
+		mtext(text=paste(round(max(powerTemp),1),"W",sep=""),side=3,
+		      at=peakPowerT,cex=.8,col=cols[3],line=-.2)
 		mtext(text=peakPowerT,side=1,at=peakPowerT,cex=.8,col=cols[3],line=.2)
+		
+		#don't show min power on repetitions where power it's in abs (like inertial)
+		if(eccon != "c" && min(power) < 0) {
+			minPowerT <- min(which(power == min(powerTemp)))
+
+			abline(v=minPowerT, col=cols[3])
+			points(minPowerT, min(powerTemp),col=cols[3])
+			mtext(text=paste(round(min(powerTemp),1),"W",sep=""),side=3,
+			      at=minPowerT,cex=.8,col=cols[3],line=-.2)
+			mtext(text=minPowerT,side=1,at=minPowerT,cex=.8,col=cols[3],line=.2)
+		}
 	}
+	
 	#time to arrive to peak power negative on con-ecc
 	if(eccon=="ce") {
 		peakPowerTneg=min(which(power == min(power)))
@@ -973,11 +1313,19 @@ textBox <- function(x,y,text,frontCol,bgCol,xpad=.1,ypad=1){
 } 
 
 
-paintPowerPeakPowerBars <- function(singleFile, title, paf, Eccon, height, n, showTTPP, showRange) {
+paintPowerPeakPowerBars <- function(singleFile, title, paf, Eccon, height, n, showTTPP, showRange) 
+{
+	#if there's one or more inertial curves: show inertia instead of mass
+	if(findInertialCurves(paf)) {
+		load = paf[,findPosInPaf("Inertia","")]
+		load = load * 10000
+	} else
+		load = paf[,findPosInPaf("Load","")]
+
+
 	pafColors=c("tomato1","tomato4",topo.colors(10)[3])
 	myNums = rownames(paf)
 	height = abs(height/10)
-	load = paf[,findPosInPaf("Load","")]
 	laterality = translateVector(as.vector(paf[,findPosInPaf("Laterality","")]))
 	
 	if(Eccon=="ecS" || Eccon=="ceS") {
@@ -1019,13 +1367,28 @@ paintPowerPeakPowerBars <- function(singleFile, title, paf, Eccon, height, n, sh
 		marginRight = marginRight -3
 
 	par(mar=c(2.5, 4, 5, marginRight))
+
+	bpAngle = 0
+	bpDensity = NULL
+	if(Eccon == "ecS") {
+		bpAngle = c(-45,-45,45,45)
+		bpDensity = c(30,30,-1,-1) #concentric will be shown solid
+	}
+
 	bp <- barplot(powerData,beside=T,col=pafColors[1:2],width=c(1.4,.6),
 			names.arg=paste(myNums," ",laterality,"\n",load,sep=""),xlim=c(1,n*3+.5),cex.name=0.8,
 			xlab="",ylab=paste(translate("Power"),"(W)"), 
-			ylim=c(lowerY,max(powerData)), xpd=FALSE) #ylim, xpd = F,  makes barplot starts high (compare between them)
+			ylim=c(lowerY,max(powerData)), xpd=FALSE,	#ylim, xpd = F,  makes barplot starts high (compare between them)
+			angle=bpAngle, density=bpDensity
+			) 
 	title(main=title,line=-2,outer=T)
 	box()
-	mtext(paste(translate("Repetition")," \n",translate("Mass")," ",sep=""),side=1,at=1,adj=1,line=1,cex=.9)
+	
+	loadWord = "Mass"
+	if(findInertialCurves(paf))
+		loadWord = "Inertia M."
+
+	mtext(paste(translate("Repetition")," \n",translate(loadWord)," ",sep=""),side=1,at=1,adj=1,line=1,cex=.9)
 	#mtext(translate("Laterality"),side=1,adj=1,line=0,cex=.9)
 
 	axisLineRight=0
@@ -1128,6 +1491,8 @@ findPosInPaf <- function(var, option) {
 		pos = 13
 	else if(var == "Laterality")
 		pos = 14
+	else if(var == "Inertia")
+		pos = 15
 	
 	if( ( var == "Speed" || var == "Power" || var == "Force") & option == "max")
 		pos=pos+1
@@ -1137,6 +1502,31 @@ findPosInPaf <- function(var, option) {
 	return(pos)
 }
 
+#see if there's any inertial curve
+#can be done by encoderConfigurationName
+#but is faster just see if inertiaMoment is != than -1.
+#But inertiaMoment is divided by 10000. So use the '> 0' to know when there's inertiaMoment
+#
+#returns TRUE if there is one or more inertial curve
+findInertialCurves <- function(paf) {
+	write("findInertialCurves",stderr())
+
+	im = paf[,findPosInPaf("Inertia", "")]
+	#write(im,stderr())
+
+	if(length(im) < 1)
+		return (FALSE)
+
+	for(i in 1:length(im)) {
+		#write(c("im: ", im[i]),stderr())
+		if(im[i] > 0) {
+			return (TRUE)
+		}
+	}
+
+	return (FALSE)
+}
+
 addUnitsAndTranslate <- function (var) {
 	if(var == "Speed")
 		return (paste(translate("Speed"),"(m/s)"))
@@ -1144,6 +1534,8 @@ addUnitsAndTranslate <- function (var) {
 		return (paste(translate("Power"),"(W)"))
 	else if(var == "Load") #or Mass
 		return (paste(translate("Mass"),"(Kg)"))
+	else if(var == "Inertia")
+		return (paste(translate("Inertia M."),"(Kg*cm^2)"))
 	else if(var == "Force")
 		return (paste(translate("Force"),"(N)"))
 
@@ -1267,18 +1659,26 @@ stroverlapArray <- function(newPoint, points) {
 
 
 #option: mean or max
-paintCrossVariables <- function (paf, varX, varY, option, isAlone, title, singleFile, Eccon, ecconVector, seriesName, do1RM, do1RMMethod, outputData1) {
+paintCrossVariables <- function (paf, varX, varY, option, isAlone, title, singleFile, Eccon, ecconVector, seriesName, do1RM, do1RMMethod, outputData1) 
+{
+	#if there's one or more inertial curves: show inertia instead of mass
+	if(varX == "Load" && findInertialCurves(paf))
+		varX = "Inertia"
+
 	x = (paf[,findPosInPaf(varX, option)])
 	y = (paf[,findPosInPaf(varY, option)])
 
-	print("seriesName")
-	print(seriesName)
+	if(varX == "Inertia")
+		x = x * 10000
+
+	#print("seriesName")
+	#print(seriesName)
 
 	colBalls = NULL
 	bgBalls = NULL
 
 	isPowerLoad = FALSE
-	if(varX == "Load" && varY == "Power")
+	if( (varX == "Load" || varX == "Inertia") && varY == "Power" )
 		isPowerLoad = TRUE
 
 	varXut = addUnitsAndTranslate(varX)
@@ -1836,7 +2236,7 @@ doProcess <- function(options)
 			dataTempFile  = dataTempFile[!is.na(dataTempFile)]
 
 			if(isInertial(inputMultiData$econfName[i])) {
-				dataTempFile = fixDisplacementInertial(
+				dataTempFile = getDisplacementInertial(
 								       dataTempFile, inputMultiData$econfName[i], 
 								       inputMultiData$econfd[i], inputMultiData$econfD[i])
 				#getDisplacementInertialBody is not needed because it's done on curve save
@@ -1938,11 +2338,11 @@ doProcess <- function(options)
 					    stringsAsFactors=F,row.names=1)
 		}
 
+
 		n=length(curves[,1])
 		quitIfNoData(n, curves, op$OutputData1)
 		
-		print("curves")
-		print(curves)
+		#print(curves, stderr())
 	
 		#find SmoothingsEC
 		SmoothingsEC = findSmoothingsEC(singleFile, displacement, curves, op$Eccon, op$SmoothingOneC)
@@ -1954,7 +2354,8 @@ doProcess <- function(options)
 
 		if(isInertial(op$EncoderConfigurationName)) 
 		{
-			displacement = fixDisplacementInertial(displacement, op$EncoderConfigurationName, op$diameter, op$diameterExt)
+			diametersPerMs = getInertialDiametersPerMs(displacement, op$diameter)
+			displacement = getDisplacementInertial(displacement, op$EncoderConfigurationName, diametersPerMs, op$diameterExt)
 		
 			displacement = getDisplacementInertialBody(0, displacement, curvesPlot, op$Title)
 			#positionStart is 0 in graph.R. It is different on capture.R because depends on the start of every repetition
@@ -1964,6 +2365,7 @@ doProcess <- function(options)
 			displacement = getDisplacement(op$EncoderConfigurationName, displacement, op$diameter, op$diameterExt)
 		}
 
+		#TODO: is this needed at all?
 		if(length(displacement)==0) {
 			plot(0,0,type="n",axes=F,xlab="",ylab="")
 			text(x=0,y=0,translate("Encoder is not connected."),cex=1.5)
@@ -1977,8 +2379,10 @@ doProcess <- function(options)
 		#print(c("position",position))
 		#print(c("displacement",displacement))
 		
-		curves=findCurves(displacement, op$Eccon, op$MinHeight, curvesPlot, op$Title)
-
+		#curves=findCurvesOld(displacement, op$Eccon, op$MinHeight, curvesPlot, op$Title)
+		curves=findCurvesNew(displacement, op$Eccon, isInertial(op$EncoderConfigurationName), 
+				     op$MinHeight, curvesPlot, op$Title)
+		
 		if(op$Analysis == "curves")
 			curvesPlot = TRUE
 
@@ -2004,13 +2408,13 @@ doProcess <- function(options)
 			}
 		}
 		
+		print("curves after reduceCurveBySpeed")
+		print(curves)
+		
 		#find SmoothingsEC
 		SmoothingsEC = findSmoothingsEC(singleFile, displacement, curves, op$Eccon, op$SmoothingOneC)
 		print(c("SmoothingsEC:",SmoothingsEC))
 		
-		print("curves after reduceCurveBySpeed")
-		print(curves)
-
 		if(curvesPlot) {
 			#/10 mm -> cm
 			for(i in 1:length(curves[,1])) { 
@@ -2069,6 +2473,7 @@ doProcess <- function(options)
 	print("Creating (op$OutputData2)4.txt with touch method...")
 	file.create(paste(op$OutputData2,"4.txt",sep=""))
 	print("Created")
+	#print(curves)
 
 	if(op$Analysis=="single") {
 		if(op$Jump>0) {
@@ -2112,9 +2517,14 @@ doProcess <- function(options)
 			#	myEccon="c"
 			#}
 
-
+			#find which SmoothingsEC is needed
+			smoothingPos <- 1
+			if(op$Jump %in% rownames(curves))
+				smoothingPos <- which(rownames(curves) == op$Jump)
+		
+			
 			paint(displacement, myEccon, myStart, myEnd,"undefined","undefined",FALSE,FALSE,
-			      1,curves[op$Jump,3],SmoothingsEC[1],op$SmoothingOneC,myMassBody,myMassExtra,
+			      1,curves[op$Jump,3],SmoothingsEC[smoothingPos],op$SmoothingOneC,myMassBody,myMassExtra,
 			      myEncoderConfigurationName,myDiameter,myDiameterExt,myAnglePush,myAngleWeight,myInertiaMomentum,myGearedDown,
 			      paste(op$Title, " ", op$Analysis, " ", myEccon, ". ", myCurveStr, sep=""),
 			      "", #subtitle
@@ -2303,7 +2713,7 @@ doProcess <- function(options)
 				}
 			}
 
-			print(c("i, curves[i,1], curves[i,2]", i, curves[i,1],curves[i,2]))
+			#print(c("i, curves[i,1], curves[i,2]", i, curves[i,1],curves[i,2]))
 
 			#if ecS go kinematics first time with "e" and second with "c"
 			myEcconKn = myEccon
@@ -2327,7 +2737,7 @@ doProcess <- function(options)
 								 myInertiaMomentum,myGearedDown,
 								 SmoothingsEC[i],op$SmoothingOneC, 
 								 g, myEcconKn, isPropulsive),
-						     myMassBody, myMassExtra, myLaterality
+						     myMassBody, myMassExtra, myLaterality, myInertiaMomentum
 						     )))
 		}
 
@@ -2339,10 +2749,10 @@ doProcess <- function(options)
 		rownames(paf)=rownames(curves)
 		
 		if(debug) {
-			print("--------CURVES (propulsive is not calculated yet) --------------")
-			print(curves)
-			print("----------PAF---------------")
-			print(paf)
+			#print("--------CURVES (propulsive is not calculated yet) --------------")
+			#print(curves)
+			#print("----------PAF---------------")
+			#print(paf)
 		}
 
 		if(op$Analysis == "powerBars") {
@@ -2370,10 +2780,10 @@ doProcess <- function(options)
 
 			ecconVector = createEcconVector(singleFile, op$Eccon, length(curves[,1]), curves[,8])
 
-			print("AnalysisVariables:")
-			print(op$AnalysisVariables[1])
-			print(op$AnalysisVariables[2])
-			print(op$AnalysisVariables[3])
+			#print("AnalysisVariables:")
+			#print(op$AnalysisVariables[1])
+			#print(op$AnalysisVariables[2])
+			#print(op$AnalysisVariables[3])
 
 			if(op$AnalysisVariables[1] == "Speed,Power") {
 				par(mar=c(5,4,5,5))
@@ -2505,9 +2915,9 @@ doProcess <- function(options)
 					"pp_ppt",
 					"meanForce", "maxForce", "maxForceT",
 			  		"mass", "massBody", "massExtra", #unneded
-					"laterality")
+					"laterality","Inertia")
 			write.csv(paf, op$OutputData1, quote=FALSE)
-			print("curves written")
+			#print("curves written")
 		}
 	}
 	if(op$Analysis=="exportCSV") {
