@@ -27,7 +27,7 @@
 #it can be printed safely to stderr. See end capture.R
 
 #used in graph.R and capture.R
-assignOptions <- function(options) {        
+assignOptions <- function(options) {    
 	return(list(
 		    File		= options[1],        
 		    OutputGraph		= options[2],
@@ -53,13 +53,11 @@ assignOptions <- function(options) {
 		    #AnalysisVariables = "0.185;method". speed1RM = 0.185m/s
 		    Analysis		= options[11],	
 		    AnalysisVariables	= unlist(strsplit(options[12], "\\;")),
-
 		    AnalysisOptions	= options[13],
-
-		    #TODO: all this have to be applicable also on ! singleFILE
 		    EncoderConfigurationName =	options[14],	#just the name of the EncoderConfiguration	
-		    diameter		= as.numeric(options[15]),	#in meters, eg: 0.0175
-		    diameterExt		= as.numeric(options[16]),	#in meters, eg: 0.0175
+		    diameter		= as.numeric(unlist(strsplit(options[15], "\\;"))), #comes in cm, will be converted to m. Since 1.5.1 can be different diameters separated by ;
+		    #diameter    = getInertialDiametersPerTick(as.numeric(unlist(strsplit("1.5; 1.75; 2.65; 3.32; 3.95; 4.07; 4.28; 4.46; 4.54; 4.77; 4.96; 5.13; 5.3; 5.55", "\\;")))),
+        diameterExt		= as.numeric(options[16]),	#comes in cm, will be converted to m
 		    anglePush 		= as.numeric(options[17]),
 		    angleWeight 	= as.numeric(options[18]),
 		    inertiaMomentum	= (as.numeric(options[19])/10000.0),	#comes in Kg*cm^2 eg: 100; convert it to Kg*m^2 eg: 0.010
@@ -148,7 +146,34 @@ extrema <- function(y, ndata = length(y), ndatam1 = ndata - 1) {
 			}
 			ncross <- nrow(cross)        
 		}
-	} 
+	}
+
+	#extrema cross working:
+	#a=c(-3,-2,-1,0,1,2,1)
+	#extrema(a)$cross
+	#     [,1] [,2]
+	#[1,]    4    4
+	#extrema(a)$ncross
+	#[1] 1
+	#
+	#But, if there's no change of direction, cross does not find anything:
+	#a=c(-3,-2,-1,0,1,2)
+	#extrema(a)$cross
+	#NULL
+	#extrema(a)$ncross
+	#[1] 0
+	#
+	#then find a cross in this situation. Find just one cross.
+	if(ncross == 0)	{
+		positiveAtStart = (y[1] >= 0)
+		for(i in 1:length(y)) {
+			if( (y[i] >= 0) != positiveAtStart) { #if there's a sign change
+				cross = rbind(cross, c(i-1,i))
+				ncross = 1
+				break
+			}
+		}
+	}
 
 	list(minindex=minindex, maxindex=maxindex, nextreme=nextreme, cross=cross, ncross=ncross)
 }
@@ -207,7 +232,6 @@ findTakeOff <- function(forceConcentric, maxSpeedTInConcentric)
 
 getSpeed <- function(displacement, smoothing) {
 	#no change affected by encoderConfiguration
-
 	return (smooth.spline( 1:length(displacement), displacement, spar=smoothing))
 }
 
@@ -217,6 +241,7 @@ getAcceleration <- function(speed) {
 }
 
 #gearedDown is positive, normally 2
+#this is not used on inertial machines
 getMass <- function(mass, gearedDown, angle) {
 	if(mass == 0)
 		return (0)
@@ -228,43 +253,10 @@ getMass <- function(mass, gearedDown, angle) {
 	return ( ( mass / gearedDown ) * sin( angle * pi / 180 ) )
 }
 
-getMassBodyByExercise <- function(massBody, exercisePercentBodyWeight) {
-	if(massBody == 0 || exercisePercentBodyWeight == 0)
-		return (0)
-	
-	return (massBody * exercisePercentBodyWeight / 100.0)
-}
-
-getMassByEncoderConfiguration <- function(encoderConfigurationName, massBody, massExtra, exercisePercentBodyWeight, gearedDown, anglePush, angleWeight)
-{
-	massBody = getMassBodyByExercise(massBody,exercisePercentBodyWeight)
-
-	if(
-	   encoderConfigurationName == "WEIGHTEDMOVPULLEYLINEARONPERSON1" ||
-	   encoderConfigurationName == "WEIGHTEDMOVPULLEYLINEARONPERSON1INV" ||
-	   encoderConfigurationName == "WEIGHTEDMOVPULLEYLINEARONPERSON2" ||
-	   encoderConfigurationName == "WEIGHTEDMOVPULLEYLINEARONPERSON2INV" ||
-	   encoderConfigurationName == "WEIGHTEDMOVPULLEYROTARYFRICTION" ||
-	   encoderConfigurationName == "WEIGHTEDMOVPULLEYROTARYAXIS" ) 
-	{
-		massExtra = getMass(massExtra, gearedDown, anglePush)
-	} else if(encoderConfigurationName == "LINEARONPLANE") {
-		massBody = getMass(massBody, gearedDown, anglePush)
-		massExtra = getMass(massExtra, gearedDown, anglePush)
-	} else if(encoderConfigurationName == "LINEARONPLANEWEIGHTDIFFANGLE") {
-		massBody = getMass(massBody, gearedDown, anglePush)
-		massExtra = getMass(massExtra, gearedDown, angleWeight)
-	}
-		
-	mass = massBody + massExtra
-	return (mass)
-}
 
 #used in alls eccons
 reduceCurveBySpeed <- function(eccon, row, startT, startH, displacement, smoothingOneC) 
 {
-	#print("at reduceCurveBySpeed")
-
 	#In 1.4.0 and before, we use smoothingOneEC on "ec", "ce"
 	#but the problem is findSmoothingsEC has problems knowing the smoothingEC when users stays stand up lot of time before jump.
         #is better to reduceCurveBySpeed first in order to remove the not-moving phase
@@ -284,6 +276,8 @@ reduceCurveBySpeed <- function(eccon, row, startT, startH, displacement, smoothi
 	#in order to reduce curve by speed, we search the cross of speed (in 0m/s)
         #before and after the peak value, but in "ec" and "ce" there are two peak values:
 	#
+	#speeds:
+	#
 	#ec         2
 	#\         / \
 	# \       /   \
@@ -310,11 +304,14 @@ reduceCurveBySpeed <- function(eccon, row, startT, startH, displacement, smoothi
 	} else if(eccon=="ce") {
 		time1 = min(which(speed$y == max(speed$y)))
 		time2 = max(which(speed$y == min(speed$y)))
-	} else {
+	} else { #c
 		speed$y=abs(speed$y)
 		time1 = min(which(speed$y == max(speed$y)))
 		time2 = max(which(speed$y == max(speed$y)))
 	}
+	
+	#write("time1, time2",stderr())
+	#write(c(time1,time2),stderr())
 
 	#now that times are defined we can work in ABS for all the curves
 	speed$y=abs(speed$y)
@@ -370,8 +367,8 @@ reduceCurveBySpeed <- function(eccon, row, startT, startH, displacement, smoothi
 #eccon="ecS" means ecSeparated. two times each curve: one for "e", one for "c"
 kinematicsF <- function(displacement, massBody, massExtra, exercisePercentBodyWeight,
 			encoderConfigurationName,diameter,diameterExt,anglePush,angleWeight,inertiaMomentum,gearedDown,
-			smoothingOneEC, smoothingOneC, g, eccon, isPropulsive) {
-
+			smoothingOneEC, smoothingOneC, g, eccon, isPropulsive)
+{
 	smoothing = 0
 	if(eccon == "c" || eccon == "e")
 		smoothing = smoothingOneC
@@ -379,7 +376,7 @@ kinematicsF <- function(displacement, massBody, massExtra, exercisePercentBodyWe
 		smoothing = smoothingOneEC
 	
 
-#print(c(" smoothing:",smoothing))
+	print(c("eccon, smoothing:",eccon, smoothing))
 
 	#x vector should contain at least 4 different values
 	if(length(displacement) >= 4)
@@ -445,17 +442,28 @@ kinematicsF <- function(displacement, massBody, massExtra, exercisePercentBodyWe
 
 	dynamics = getDynamics(encoderConfigurationName,
 			speed$y, accel$y, massBody, massExtra, exercisePercentBodyWeight, gearedDown, anglePush, angleWeight,
-			displacement, diameter, diameterExt, inertiaMomentum, smoothing)
+			displacement, diameter, inertiaMomentum, smoothing)
 	mass = dynamics$mass
 	force = dynamics$force
 	power = dynamics$power
 
+	start <- 1
+	end <- length(speed$y)
 
 	if( isPropulsive && ( eccon== "c" || eccon == "ec" ) )
-		return(list(speedy=speed$y[1:propulsiveEnd], accely=accel$y[1:propulsiveEnd], 
-			    force=force[1:propulsiveEnd], power=power[1:propulsiveEnd], mass=mass))
-	else
-		return(list(speedy=speed$y, accely=accel$y, force=force, power=power, mass=mass))
+		end <- propulsiveEnd
+
+	if(inertiaMomentum > 0 && (eccon == "e" || eccon == "ec") && accel$y[1] < 0)
+		start <- min(which(accel$y > 0))
+
+	#print(c("kinematicsF start end",start,end))
+
+	return(list(
+		    speedy = speed$y[start:end], 
+		    accely = accel$y[start:end], 
+		    force = force[start:end], 
+		    power = power[start:end], 
+		    mass = mass))
 }
 
 findECPhases <- function(displacement,speed) {
@@ -479,6 +487,7 @@ findECPhases <- function(displacement,speed) {
 	#print("speed.ext-Cross")
 	#print(speed.ext$cross[,1])
 	#print("search min cross: crossMinRow")
+
 	crossMinRow=which(speed.ext$cross[,1] > searchMinSpeedEnd & speed.ext$cross[,1] < searchMaxSpeedIni)
 	#print(crossMinRow)
 			
@@ -560,7 +569,7 @@ findPropulsiveEnd <- function(accel, concentric, maxSpeedTInConcentric,
 return (propulsiveEnd)
 }
 
-pafGenerate <- function(eccon, kinematics, massBody, massExtra, laterality) {
+pafGenerate <- function(eccon, kinematics, massBody, massExtra, laterality, inertiaMomentum) {
 	#print("speed$y")
 	#print(kinematics$speedy)
 
@@ -569,10 +578,12 @@ pafGenerate <- function(eccon, kinematics, massBody, massExtra, laterality) {
 	maxSpeed <- max(abs(kinematics$speedy))
 	maxSpeedT <- min(which(abs(kinematics$speedy) == maxSpeed))
 
-	if(eccon == "c")
-		meanPower <- mean(kinematics$power)
-	else
+	meanPower <- mean(kinematics$power)
+	
+	if(eccon != "c") {
+		meanSpeed <- mean(abs(kinematics$speedy))
 		meanPower <- mean(abs(kinematics$power))
+	}
 
 	#print(c("eccon meanPowerSigned meanPowerABS",eccon, mean(kinematics$power), mean(abs(kinematics$power))))
 	#print("kinematics$power")
@@ -595,43 +606,78 @@ pafGenerate <- function(eccon, kinematics, massBody, massExtra, laterality) {
 			  meanSpeed, maxSpeed, maxSpeedT,
 			  meanPower, peakPower, peakPowerT, pp_ppt,
 			  meanForce, maxForce, maxForceT,
-			  kinematics$mass, massBody, massExtra, laterality)) #kinematics$mass is Load
+			  kinematics$mass, massBody, massExtra,		#kinematics$mass is Load
+			  laterality, inertiaMomentum)) 
 }
 
 isInertial <- function(encoderConfigurationName) {
 	if(encoderConfigurationName == "LINEARINERTIAL" ||
 	   encoderConfigurationName == "ROTARYFRICTIONSIDEINERTIAL" ||
 	   encoderConfigurationName == "ROTARYFRICTIONAXISINERTIAL" ||
-	   encoderConfigurationName == "ROTARYAXISINERTIAL") 
+	   encoderConfigurationName == "ROTARYFRICTIONSIDEINERTIALLATERAL" || 
+	   encoderConfigurationName == "ROTARYFRICTIONAXISINERTIALLATERAL" ||
+	   encoderConfigurationName == "ROTARYFRICTIONSIDEINERTIALMOVPULLEY" || 
+	   encoderConfigurationName == "ROTARYFRICTIONAXISINERTIALMOVPULLEY" ||
+	   encoderConfigurationName == "ROTARYAXISINERTIAL" ||
+	   encoderConfigurationName == "ROTARYAXISINERTIALLATERAL" || 
+	   encoderConfigurationName == "ROTARYAXISINERTIALMOVPULLEY"
+	   )
 		return(TRUE)
 	else
 		return(FALSE)
 }
 
+getMassBodyByExercise <- function(massBody, exercisePercentBodyWeight) {
+  return (massBody * exercisePercentBodyWeight / 100.0)
+}
+
 getDynamics <- function(encoderConfigurationName,
 			speed, accel, massBody, massExtra, exercisePercentBodyWeight, gearedDown, anglePush, angleWeight,
-			displacement, diameter, diameterExt, inertiaMomentum, smoothing)
+			displacement, diameter, inertiaMomentum, smoothing)
 {
-	mass = getMassByEncoderConfiguration (encoderConfigurationName, massBody, massExtra, exercisePercentBodyWeight, gearedDown, anglePush, angleWeight)
-
-	if(isInertial(encoderConfigurationName))
-		return (getDynamicsInertial(encoderConfigurationName, displacement, diameter, diameterExt, mass, inertiaMomentum, smoothing))
-	else 
-		return (getDynamicsNotInertial (encoderConfigurationName, speed, accel, mass, exercisePercentBodyWeight, gearedDown, anglePush, angleWeight))
+  massBody = getMassBodyByExercise(massBody,exercisePercentBodyWeight)
+  
+  if(
+    encoderConfigurationName == "WEIGHTEDMOVPULLEYLINEARONPERSON1" ||
+      encoderConfigurationName == "WEIGHTEDMOVPULLEYLINEARONPERSON1INV" ||
+      encoderConfigurationName == "WEIGHTEDMOVPULLEYLINEARONPERSON2" ||
+      encoderConfigurationName == "WEIGHTEDMOVPULLEYLINEARONPERSON2INV" ||
+      encoderConfigurationName == "WEIGHTEDMOVPULLEYROTARYFRICTION" ||
+      encoderConfigurationName == "WEIGHTEDMOVPULLEYROTARYAXIS" ) 
+  {
+    massExtra = getMass(massExtra, gearedDown, anglePush)
+  } 
+  
+  massTotal = massBody + massExtra
+  
+  if(isInertial(encoderConfigurationName))
+    return (getDynamicsInertial(encoderConfigurationName, displacement, diameter, massTotal, inertiaMomentum, smoothing))
+  else 
+    return (getDynamicsNotInertial (encoderConfigurationName, speed, accel, 
+                                    massBody, massExtra, massTotal, 
+                                    exercisePercentBodyWeight, gearedDown, anglePush, angleWeight))
 }
 
 #mass extra can be connected to body or connected to a pulley depending on encoderConfiguration
-getDynamicsNotInertial <- function(encoderConfigurationName, speed, accel, mass, exercisePercentBodyWeight, gearedDown, anglePush, angleWeight) 
-{
-	force <- mass*(accel+g)	#g:9.81 (used when movement is against gravity)
+getDynamicsNotInertial <- function(encoderConfigurationName, speed, accel, 
+                                   massBody, massExtra, massTotal,
+                                   exercisePercentBodyWeight, gearedDown, anglePush, angleWeight) 
+{ 
+  force = NULL
+  if(encoderConfigurationName == "LINEARONPLANEWEIGHTDIFFANGLE") {
+    force <- massBody*(accel + g*sin(anglePush * pi / 180)) + massExtra*(g*sin(angleWeight * pi / 180) + accel)
+  } else if(encoderConfigurationName == "LINEARONPLANE"){
+    force <- (massBody + massExtra)*(a + g*sin(anglePush * pi / 180))
+  } else {
+  	force <- massTotal*(accel+g)	#g:9.81 (used when movement is against gravity)
+  }
 
 	power <- force*speed
 
-	return(list(mass=mass, force=force, power=power))
+	return(list(mass=massTotal, force=force, power=power))
 }
 
-#d: diameter axis
-#D: diameter external (disc)
+#diameter: diameter of the axis (where string is wrapped)
 #angle: angle (rotation of disc) in radians
 #angleSpeed: speed of angle
 #angleAccel: acceleration of angle
@@ -640,8 +686,9 @@ getDynamicsNotInertial <- function(encoderConfigurationName, speed, accel, mass,
 #  ROTARYFRICTIONSIDEINERTIAL Rotary friction encoder connected to inertial machine on the side of the disc
 #  ROTARYFRICTIONAXISINERTIAL Rotary friction encoder connected to inertial machine on the axis
 #  ROTARYAXISINERTIAL Rotary axis encoder  connected to inertial machine on the axis
+#  ROTARYAXISINERTIALMOVPULLEY Rotari axis encoder connected to inertial machine on the axis and the subject pulling from a moving pulley
 
-getDynamicsInertial <- function(encoderConfigurationName, displacement, d, D, mass, inertiaMomentum, smoothing)
+getDynamicsInertial <- function(encoderConfigurationName, displacement, diameter, mass, inertiaMomentum, smoothing)
 {
 	speed = getSpeed(displacement, smoothing) #mm/ms == m/s 
 
@@ -659,45 +706,134 @@ getDynamicsInertial <- function(encoderConfigurationName, displacement, d, D, ma
 	#----------------------
 
 	position.m = abs(cumsum(displacement)) / 1000 #m
-	d.m = d / 100 #cm -> m
-	D.m = D / 100 #cm -> m
-
-	angle = position.m * 2 / d.m
-	angleSpeed = speed * 2 / d.m
-	angleAccel = accel * 2 / d.m
-
-	force = abs(inertiaMomentum * angleAccel) * (2 / d.m) + mass * (accel + g)
-	power = abs((inertiaMomentum * angleAccel) * angleSpeed) + mass * (accel + g) * speed
-	powerBody = mass * (accel + g) * speed
-	powerWheel = abs((inertiaMomentum * angleAccel) * angleSpeed)
-
-	#print(c("displacement",displacement))
-	#print(c("displacement cumsum",cumsum(displacement)))
-	#print(c("inertia momentum",inertiaMomentum))
-        #print(c("d",d))
-        #print(c("mass",mass))
-        #print(c("g",g))
-        #print(c("max angle",max(abs(angle))))
-	#print(c("max angleSpeed",max(abs(angleSpeed))))
-	#print(c("max angleAccel",max(abs(angleAccel))))
-	#print(c("speed",speed))
-	#print(c("accel",accel))
-	#print(c("max force",max(abs(force))))
-	#print(c("max power at inertial",max(abs(power))))
-	#print(c("powerBody",powerBody[1000]))
-	#print(c("powerWheel",powerWheel[1000]))
-	#print(c("d.m, D.m", d.m, D.m))
-	#print(c("max angle, max pos", max(angle), max(position.m)))
+	diameter.m = diameter / 100 #cm -> m
+  
+  if(encoderConfigurationName == "ROTARYAXISINERTIAL" ||
+       encoderConfigurationName == "ROTARYFRICTIONSIDEINERTIAL" ||
+       encoderConfigurationName == "ROTARYFRICTIONAXISINERTIAL" ||
+       encoderConfigurationName == "LINEARINERTIAL"){
+    angle = position.m * 2 / diameter.m
+    angleSpeed = speed * 2 / diameter.m
+    angleAccel = accel * 2 / diameter.m
+    force = abs(inertiaMomentum * angleAccel) * (2 / diameter.m) + mass * (accel + g)
+    power = abs((inertiaMomentum * angleAccel) * angleSpeed) + mass * (accel + g) * speed
+  } else if(encoderConfigurationName == "ROTARYAXISINERTIALMOVPULLEY" ||
+              encoderConfigurationName == "ROTARYFRICTIONAXISINERTIALMOVPULLEY" ||
+              encoderConfigurationName == "ROTARYFRICTIONSIDEINERTIALMOVPULLEY"){
+    angle = position.m * 4 / diameter.m
+    angleSpeed = speed * 4 / diameter.m
+    angleAccel = accel * 4 / diameter.m
+    force = abs(inertiaMomentum * angleAccel) * (2 / diameter.m) + mass * (accel + g)
+    power = abs((inertiaMomentum * angleAccel) * angleSpeed) + mass * (accel + g) * speed
+  } else if(encoderConfigurationName == "ROTARYAXISINERTIALLATERAL" ||
+              encoderConfigurationName == "ROTARYFRICTIONAXISINERTIALLATERAL" ||
+              encoderConfigurationName == "ROTARYFRICTIONSIDEINERTIALLATERAL"){
+    angle = position.m * 2 / diameter.m
+    angleSpeed = speed * 2 / diameter.m
+    angleAccel = accel * 2 / diameter.m
+    force = abs(inertiaMomentum * angleAccel) * (2 / diameter.m) + mass * accel
+    power = abs((inertiaMomentum * angleAccel) * angleSpeed) + mass * accel * speed
+  }
 
 	return(list(displacement=displacement, mass=mass, force=force, power=power))
 }
 
 
-#separate phases using initial height of full extended person
-#this methods replaces getDisplacement and fixRawdataInertial
-#here comes a signal: (singleFile)
-#it shows the disc rotation and the person movement
 
+#in signals and curves, need to do conversions (invert, diameter)
+getDisplacement <- function(encoderConfigurationName, displacement, diameter, diameterExt) {
+	#no change
+	#WEIGHTEDMOVPULLEYLINEARONPERSON1, WEIGHTEDMOVPULLEYLINEARONPERSON1INV,
+	#WEIGHTEDMOVPULLEYLINEARONPERSON2, WEIGHTEDMOVPULLEYLINEARONPERSON2INV,
+	#LINEARONPLANE
+	#ROTARYFRICTIONSIDE
+	#WEIGHTEDMOVPULLEYROTARYFRICTION
+  #ROTARYAXISINERTIALMOVPULLEY
+
+  if(
+	   encoderConfigurationName == "LINEARINVERTED" ||
+	   encoderConfigurationName == "WEIGHTEDMOVPULLEYLINEARONPERSON1INV" ||
+	   encoderConfigurationName == "WEIGHTEDMOVPULLEYLINEARONPERSON2INV") 
+	  #On inverted modes the direction of the displacement is changed
+  {
+	  displacement = -displacement
+  } else if(encoderConfigurationName == "WEIGHTEDMOVPULLEYONLINEARENCODER") 
+  {
+	  #On geared down machines the displacement of the subject is multiplied by gearedDown
+	  #default is: gearedDown = 2. Future maybe this will be a parameter
+	  displacement = displacement * 2
+  } else if(encoderConfigurationName == "ROTARYFRICTIONAXIS") 
+  {
+	  #On rotary friction axis the displacement of the subject is proportional to the axis diameter
+	  #and inversely proportional to the diameter where the encoder is coupled
+	  displacement = displacement * diameter / diameterExt
+  } else if(encoderConfigurationName == "ROTARYAXIS" || 
+	    encoderConfigurationName == "WEIGHTEDMOVPULLEYROTARYAXIS") 
+  {
+	  #On rotary encoders attached to fixed pulleys next to subjects (see config 1 and 3 in interface),
+	  #the displacement of the subject is anlge * radius
+	  ticksRotaryEncoder = 200 #our rotary axis encoder sends 200 ticks per revolution
+	  #The angle rotated by the pulley is (ticks / ticksRotaryEncoder) * 2 * pi
+	  #The radium in mm is diameter * 1000 / 2
+	  displacement = ( displacement / ticksRotaryEncoder ) * pi * ( diameter * 1000 )
+  }
+		
+	return(displacement)
+}
+
+#This function converts angular information from rotary encoder to linear information like linear encoder
+#This is NOT the displacement of the person because con-ec phases roll in the same direction
+#This is solved by the function getDisplacementInertialBody
+getDisplacementInertial <- function(displacement, encoderConfigurationName, diameter, diameterExt)
+{
+	write("at getDisplacementInertial", stderr())
+
+	#scanned displacement is ticks of rotary axis encoder
+	#now convert it to mm of body displacement
+	if(encoderConfigurationName == "ROTARYAXISINERTIAL" ||
+	     encoderConfigurationName == "ROTARYAXISINERTIALLATERAL") {
+		displacementMeters = displacement / 1000 #mm -> m
+		diameterMeters = diameter / 100 #cm -> m
+		ticksRotaryEncoder = 200 #our rotary axis encoder send 200 ticks per turn
+		#angle in radians
+		angle = cumsum(displacementMeters * 1000) * 2 * pi / ticksRotaryEncoder
+		position = angle * diameterMeters / 2
+		position = position * 1000	#m -> mm
+		#this is to make "inverted cumsum"
+		displacement = diff(position) #this displacement is going to be used now
+		displacement = c(displacement[1],displacement) #this is to recuperate the lost 1st value in the diff operation
+	} else if(encoderConfigurationName == "ROTARYFRICTIONSIDEINERTIAL" ||
+              encoderConfigurationName == "ROTARYFRICTIONSIDEINERTIALLATERAL"){
+	  displacement = displacement * diameter / diameterExt #displacement of the axis
+	} else if(encoderConfigurationName == "ROTARYFRICTIONAXISINERTIALMOVPULLEY"){
+	  displacement = 2 * displacement #twice the displacement of the axis
+	} else if(encoderConfigurationName == "ROTARYFRICTIONSIDEINERTIALMOVPULLEY"){
+	  displacement = 2 * displacement * diameter / diameterExt #twice the displacement of the axis
+	} else if(encoderConfigurationName == "ROTARYAXISINERTIALMOVPULLEY"){
+	  displacementMeters = displacement / 1000 #mm -> m
+	  diameterMeters = diameter / 100 #cm -> m
+	  ticksRotaryEncoder = 200 #our rotary axis encoder send 200 ticks per turn
+	  #angle in radians
+	  angle = cumsum(displacementMeters * 1000) * 2 * pi / ticksRotaryEncoder
+	  position = angle * diameterMeters / 2
+	  position = position * 500	#m -> mm and the rope moves twice as the body
+	  #this is to make "inverted cumsum"
+	  displacement = diff(position) #this displacement is going to be used now
+	  displacement = c(displacement[1],displacement) #this is to recuperate the lost 1st value in the diff operation
+	}
+	
+	
+	return (displacement)
+}
+
+
+#Converts from mm of displacement on the encoder
+#to mm of displacement of the person	
+
+#separate phases using initial height of full extended person
+#here comes a signal: (singleFile)
+#it can show graph of the disc rotation and the person movement
+	
 #positionStart is the height at the start of the curve. It's used only on realtime capture.
 #displacementPerson has to be adjusted for every repetition using the positionStart relative to the start of the movement
 #Eg, at start of the capture position is always 0, then goes down (first eccentric phase), and then starts con-ecc, con-ecc, con-ecc, ...
@@ -730,7 +866,10 @@ getDisplacementInertialBody <- function(positionStart, displacement, draw, title
 		#firstDownPhaseTime = position.ext$minindex[1]
 		#downHeight = abs(position[1] - position[firstDownPhaseTime])
 	}
-		
+	
+	#This is the main part.
+	#Converts from mm of displacement on the encoder
+	#to mm of displacement of the person	
 	positionPerson = cumsum(displacement)
 	positionPerson = positionPerson + positionStart
 	positionPerson = abs(positionPerson)*-1
@@ -742,6 +881,11 @@ getDisplacementInertialBody <- function(positionStart, displacement, draw, title
 	#don't use it
 	#displacementPerson = c(positionStart,diff(positionPerson))
 	#better have it starting with 0 and then speed calculations... will be correct
+	#displacementPerson = c(positionPerson[1],diff(positionPerson))
+	#displacementPerson = diff(positionPerson)
+	#displacementPerson = c(displacementPerson[1],displacementPerson) #this is to recuperate the lost 1st value in the diff operation
+
+	#Important: In this case, as written aboce, the first 0 should be a 0, don't touch it!
 	displacementPerson = c(0,diff(positionPerson))
 
 	#write(displacementPerson,stderr())
@@ -768,60 +912,66 @@ getDisplacementInertialBody <- function(positionStart, displacement, draw, title
 }
 
 
-#in signals and curves, need to do conversions (invert, inertiaMomentum, diameter)
-#we use 'data' variable because can be position or displacement
-getDisplacement <- function(encoderConfigurationName, data, diameter, diameterExt) {
-	#no change
-	#WEIGHTEDMOVPULLEYLINEARONPERSON1, WEIGHTEDMOVPULLEYLINEARONPERSON1INV,
-	#WEIGHTEDMOVPULLEYLINEARONPERSON2, WEIGHTEDMOVPULLEYLINEARONPERSON2INV,
-	#LINEARONPLANE
-	#ROTARYFRICTIONSIDE
-	#WEIGHTEDMOVPULLEYROTARYFRICTION
+#Read a double vector indicating the initial diameter of every loop of the rope
+#plus the final diameter of the last loop and returns a dataframe with the radius
+#correspending to the total number of ticks of the encoder
+#This can be run only once per machine
 
-	if(
-	   encoderConfigurationName == "LINEARINVERTED" ||
-	   encoderConfigurationName == "WEIGHTEDMOVPULLEYLINEARONPERSON1INV" ||
-	   encoderConfigurationName == "WEIGHTEDMOVPULLEYLINEARONPERSON2INV") 
-	{
-		data = -data
-	} else if(encoderConfigurationName == "WEIGHTEDMOVPULLEYONLINEARENCODER") {
-		#default is: gearedDown = 2. Future maybe this will be a parameter
-		data = data *2
-	} else if(encoderConfigurationName == "ROTARYFRICTIONAXIS") {
-		data = data * diameter / diameterExt
-	} else if(encoderConfigurationName == "ROTARYAXIS" || 
-		  encoderConfigurationName == "WEIGHTEDMOVPULLEYROTARYAXIS") {
-		ticksRotaryEncoder = 200 #our rotary axis encoder send 200 ticks by turn
-		#diameter m -> mm
-		data = ( data / ticksRotaryEncoder ) * 2 * pi * ( diameter * 1000 / 2 )
-	}
-		
-	return(data)
-}
-
-fixDisplacementInertial <- function(displacement, encoderConfigurationName, diameter, diameterExt)
+# Example of input of the sequence of the loop and diameter of the loop
+# We use diameters but in the next step we convert to radii
+# d_vector <- c(1.5, 1.5, 1.5, 1.5, 2, 2.5, 2.7, 2.9, 2.95, 3)
+getInertialDiametersPerTick <- function(d_vector)
 {
-	#scanned displacement is ticks of rotary axis encoder
-	#now convert it to mm of body displacement
-	if(encoderConfigurationName == "ROTARYAXISINERTIAL") {
-		displacementMeters = displacement / 1000 #mm -> m
-		diameterMeters = diameter / 100 #cm -> m
-
-		ticksRotaryEncoder = 200 #our rotary axis encoder send 200 ticks by turn
-		#angle in radians
-		angle = cumsum(displacementMeters * 1000) * 2 * pi / ticksRotaryEncoder
-		position = angle * diameterMeters / 2
-		position = position * 1000	#m -> mm
-		#this is to make "inverted cumsum"
-		displacement = c(0,diff(position)) #this displacement is going to be used now
-	}
-
-	#on friction side: know displacement of the "person"
-	if(encoderConfigurationName == "ROTARYFRICTIONSIDEINERTIAL")
-	{
-		displacement = displacement * diameter / diameterExt #displacement of the axis
-	}
-	
-	return (displacement)
+  #If only one diameter is returned, we assume that the diameter is constant
+  #and only a double is returned
+  if (length(d_vector) == 1){
+    return(d_vector)
+  }
+  
+  # Numerating the loops of the rope
+  d <- matrix(c(seq(from=0, to=(length(d_vector) -1), by=1), d_vector), ncol=2)
+  
+  # Converting the number of the loop to ticks of the encoder
+  d[,1] <- d[,1]*200
+  
+  # Adding an extra point at the begining of the diameters matrix to match better the first point
+  x1 <- d[1,1]
+  y1 <- d[1,2]
+  x2 <- d[2,1]
+  y2 <- d[2,2]
+  lambda <- 200
+  x0 <- x1 - lambda
+  y0 <- y1 - lambda*(y2 - y1)/(x2 - x1)
+  p0 <- matrix(c(x0, y0), ncol=2)
+  d <- rbind(p0, d)
+  
+  # Adding an extra point at the end of the diameters matrix to match better the last point
+  last <- length(d[,1])
+  x1 <- d[(last - 1),1]
+  y1 <- d[(last - 1),2]
+  x2 <- d[last,1]
+  y2 <- d[last,2]
+  lambda <- 200
+  xFinal <- x2 + lambda
+  yFinal <- y2 + lambda*(y2 - y1)/(x2 - x1)
+  pFinal <- matrix(c(xFinal, yFinal), ncol=2)
+  d <- rbind(d, pFinal)
+  
+  
+  # Linear interpolation of the radius across the lenght of the measurement of the diameters
+  #d.approx <- approx(x=d[,1], y=d[,2], seq(from=1, to=d[length(d[,1]),1]))
+  d.smoothed <- smooth.spline(d, spar=0.4)
+  d.approx <- predict(d.smoothed, 0:d[length(d[,1]), 1],0)
+  return(d.approx$y)
+}
+#Returns the instant diameter every milisecond, depending on the displacement of the movement
+getInertialDiametersPerMs <- function(displacement, diametersPerTick)
+{
+  if (length(diametersPerTick) == 1) {
+    return(diametersPerTick)
+  }
+  
+  diameter <- diametersPerTick[abs(cumsum(displacement)) + 1]
+  return(diameter)
 }
 
