@@ -45,6 +45,7 @@ public class Constants
 		"Teng Wei Hua (wadedang@gmail.com)\n\t" + Catalog.GetString("Translation of Firmware to C.") + "\n\t" +
 			Catalog.GetString("New firmware features.") + " " + Catalog.GetString("Encoder hardware layer.") + "\n",
 		"Juan Gonzalez Gómez (http://www.iearobotics.com)\n\t" + Catalog.GetString("Skypic, Chronopic, connection between hardware and software.") + "\n", 
+		"Ferran Suárez Rodríguez (ferransuarez2@gmail.com)\n\t" + Catalog.GetString("Chronopic reaction time advanced implementation.") + "\n",
 		"Ricardo Gómez González (http://www.iearobotics.com)\n\t" + Catalog.GetString("Chronopic3 industrial prototype.") + "\n",
 		"Juan Fernando Pardo (juanfer@juanfer.com.ar)\n\t" + "Chronopic2."
 	};
@@ -53,7 +54,8 @@ public class Constants
 		"Anna Padullés (hardware@chronojump.org)\n",
 		"Xavier Padullés (testing@chronojump.org)\n",
 		"Teng Wei Hua (wadedang@gmail.com)\n",
-		"Xavier de Blas Foix (info@chronojump.org)"
+		"Xavier de Blas Foix (info@chronojump.org)\n",
+		"Ferran Suárez Rodríguez (ferransuarez2@gmail.com)\n"
 	};
 	public static string [] AuthorsMath = {
 		"Carlos J. Gil Bellosta (http://www.datanalytics.com)\n",
@@ -490,6 +492,13 @@ public class Constants
 	public static string FoundUSBSerialPortsString = Catalog.GetString("USB-serial ports found:"); 
 	public static string NotFoundUSBSerialPortsString = Catalog.GetString("Not found any USB-serial ports.") + " " + Catalog.GetString("Is Chronopic connected?"); 
 
+	public static string ChronopicDetecting = Catalog.GetString("Detecting ...");
+	public static string ChronopicNeedTouch = Catalog.GetString("Touch device.");
+
+	public static string FindDriverNeed = Catalog.GetString("Chronopic driver has to be installed.");
+	public static string FindDriverWindows = Catalog.GetString("If you have problems connecting with Chronopic, ensure you have the <b>driver</b> installed at 'Windows Start Menu / Chronojump / Install Chronopic driver'."); 
+	public static string FindDriverOthers = Catalog.GetString("Check Chronojump software website.");
+
 //	public static System.Media.SystemSound SoundCanStart = System.Media.SystemSounds.Question; 
 //	public static System.Media.SystemSounds SoundGood = System.Media.SystemSounds.Exclamation; 
 //	public static System.Media.SystemSounds SoundBad = System.Media.SystemSounds.Beep; 
@@ -737,6 +746,8 @@ public class Constants
 
 	public static double EncoderErrorCode = -1;
 	
+	public static string FileNameEncoderImagePending = "encoder-image-pending.png";
+	
 	//three encoder types
 	public static string FileNameEncoderTypeLinear = "encoder-linear.png";
 	public static string FileNameEncoderTypeRotaryFriction = "encoder-rotary-friction.png";
@@ -760,25 +771,37 @@ public class Constants
 	public static string FileNameEncoderFrictionAxis = "encoder-rotary-friction-pulley-axis.png";
 	public static string FileNameEncoderFrictionSideInertial = "encoder-rotary-friction-side-inertial.png";
 	public static string FileNameEncoderFrictionAxisInertial = "encoder-rotary-friction-axis-inertial.png";
+	public static string FileNameEncoderFrictionSideInertialLateral = "encoder-rotary-friction-side-inertial-lateral.png";
+	public static string FileNameEncoderFrictionAxisInertialLateral = "encoder-rotary-friction-axis-inertial-lateral.png";
+	public static string FileNameEncoderFrictionSideInertialMovPulley = "encoder-rotary-friction-side-inertial-mov-pulley.png";
+	public static string FileNameEncoderFrictionAxisInertialMovPulley = "encoder-rotary-friction-axis-inertial-mov-pulley.png";
 	public static string FileNameEncoderFrictionWithMovPulley = "encoder-rotary-friction-on-fixed-pulley-with-weighted-moving-pulley.png";
 
 	//rotary axis
 	public static string FileNameEncoderRotaryAxisOnAxis = "encoder-rotary-axis-pulley-axis.png";
 	public static string FileNameEncoderAxisInertial = "encoder-rotary-axis-inertial.png";
+	public static string FileNameEncoderAxisInertialLateral = "encoder-rotary-axis-inertial-lateral.png";
+	public static string FileNameEncoderAxisInertialMovPulley = "encoder-rotary-axis-inertial-mov-pulley.png";
 	public static string FileNameEncoderAxisWithMovPulley = "encoder-rotary-axis-on-fixed-pulley-with-weighted-moving-pulley.png";
 	
 	public static string FileNameEncoderCalculeIM = "encoder-calcule-im.png";	
 
 	public enum EncoderConfigurationNames { //this names are used on graph.R change there also if needed
+		// ---- LINEAR ----
 		LINEAR, LINEARINVERTED, LINEARINERTIAL, 
 		WEIGHTEDMOVPULLEYLINEARONPERSON1, WEIGHTEDMOVPULLEYLINEARONPERSON1INV,
 		WEIGHTEDMOVPULLEYLINEARONPERSON2, WEIGHTEDMOVPULLEYLINEARONPERSON2INV,
 		WEIGHTEDMOVPULLEYONLINEARENCODER, 
 		LINEARONPLANE, LINEARONPLANEWEIGHTDIFFANGLE, 
-		ROTARYFRICTIONSIDE, ROTARYFRICTIONAXIS,				//friction
-		ROTARYFRICTIONSIDEINERTIAL, ROTARYFRICTIONAXISINERTIAL,		//friction
-		WEIGHTEDMOVPULLEYROTARYFRICTION,				//friction
-		ROTARYAXIS, ROTARYAXISINERTIAL, WEIGHTEDMOVPULLEYROTARYAXIS	//axis
+		// ---- ROTARY FRICTION ----
+		ROTARYFRICTIONSIDE, ROTARYFRICTIONAXIS,
+		WEIGHTEDMOVPULLEYROTARYFRICTION,
+		ROTARYFRICTIONSIDEINERTIAL, ROTARYFRICTIONAXISINERTIAL,
+		ROTARYFRICTIONSIDEINERTIALLATERAL, ROTARYFRICTIONAXISINERTIALLATERAL,
+		ROTARYFRICTIONSIDEINERTIALMOVPULLEY, ROTARYFRICTIONAXISINERTIALMOVPULLEY,
+		// ---- ROTARY AXIS ----
+		ROTARYAXIS, WEIGHTEDMOVPULLEYROTARYAXIS,
+		ROTARYAXISINERTIAL, ROTARYAXISINERTIALLATERAL, ROTARYAXISINERTIALMOVPULLEY
 	}
 
 	public static string DefaultEncoderConfigurationCode = "Linear - barbell";
@@ -789,6 +812,8 @@ public class Constants
 
 	public static string MeanSpeed = "Mean speed";
 	public static string MaxSpeed = "Max speed";
+	public static string MeanForce = "Mean force";
+	public static string MaxForce = "Max force";
 	public static string MeanPower = "Mean power";
 	public static string PeakPower = "Peak power";
 		
@@ -844,7 +869,8 @@ public class Constants
 		"Mean speed in concentric propulsive phase",
 		"Sorry, no repetitions matched your criteria.",
 		"Need at least three jumps",
-		"Laterality", "RL", "R", "L"
+		"Laterality", "RL", "R", "L",
+		"Inertia M."
 	};
 	/*
 	 * written here in order to be translated
@@ -885,6 +911,7 @@ public class Constants
 		Catalog.GetString("Mean speed in concentric propulsive phase"),
 		Catalog.GetString("Sorry, no repetitions matched your criteria."),
 		Catalog.GetString("Need at least three jumps"),
-		Catalog.GetString("Laterality"), Catalog.GetString("RL"), Catalog.GetString("R"), Catalog.GetString("L")
+		Catalog.GetString("Laterality"), Catalog.GetString("RL"), Catalog.GetString("R"), Catalog.GetString("L"),
+		Catalog.GetString("Inertia M.")
 	};
 }
