@@ -91,12 +91,24 @@ public class EncoderParams
 		this.decimalSeparator = decimalSeparator;
 	}
 	
-	public string ToString2 (string sep) 
+	public string ToStringROptions () 
 	{
-		return minHeight + sep + exercisePercentBodyWeight + sep + massBody + sep + massExtra +
-			sep + eccon + sep + analysis + sep + analysisVariables + sep + analysisOptions + 
-			sep + encoderConfiguration.ToString(sep, true) +
-			sep + smoothCon + sep + curve + sep + width + sep + height + sep + decimalSeparator;
+		return 
+			"#minHeight\n" + 	minHeight + "\n" + 
+			"#exercisePercentBodyWeight\n" + exercisePercentBodyWeight + "\n" + 
+			"#massBody\n" + 	massBody + "\n" + 
+			"#massExtra\n" + 	massExtra + "\n" + 
+			"#eccon\n" + 		eccon + "\n" + 
+			"#analysis\n" + 	analysis + "\n" + 
+			"#analysisVariables\n" + analysisVariables + "\n" + 
+			"#analysisOptions\n" + analysisOptions + "\n" + 
+			encoderConfiguration.ToStringOutput(EncoderConfiguration.Outputs.ROPTIONS) + "\n" +
+			"#smoothCon\n" + 	smoothCon + "\n" + 
+			"#curve\n" + 		curve + "\n" + 
+			"#width\n" + 		width + "\n" + 
+			"#height\n" + 		height + "\n" + 
+			"#decimalSeparator\n" + decimalSeparator
+			;
 	}
 	
 	public string Analysis {
@@ -177,14 +189,20 @@ public class EncoderGraphROptions
 	}
 
 	public override string ToString() {
-		return inputData + "\n" + 
-			outputGraph + "\n" + outputData1 + "\n" + 
-			outputData2 + "\n" + specialData + "\n" + 
-			ep.ToString2("\n") + "\n" + title + "\n" + operatingSystem + "\n" +
-			scriptUtilR + "\n" + scriptNeuromuscularProfile + "\n" +
-			englishWords + "\n" +
-			translatedWords + "\n" + 
-			scriptGraphR + "\n";
+		return 
+			"#inputdata\n" + 	inputData + "\n" + 
+			"#outputgraph\n" + 	outputGraph + "\n" + 
+			"#outputdata1\n" + 	outputData1 + "\n" + 
+			"#outputdata2\n" + 	outputData2 + "\n" + 
+			"#specialdata\n" + 	specialData + "\n" + 
+			ep.ToStringROptions() + "\n" + 
+			"#title\n" + 		title + "\n" + 
+			"#operatingsystem\n" + 	operatingSystem + "\n" +
+			"#scriptUtilR\n" + 	scriptUtilR + "\n" + 
+			"#scriptNeuromuscularProfile\n" + scriptNeuromuscularProfile + "\n" +
+			"#englishWords\n" + 	englishWords + "\n" +
+			"#translatedWords\n" + 	translatedWords + "\n" + 
+			"#scriptGraphR\n" + 	scriptGraphR + "\n";
 	}
 
 	~EncoderGraphROptions() {}
@@ -520,7 +538,7 @@ public class EncoderSQL
 		this.status = status;
 		this.videoURL = videoURL;
 		this.encoderConfiguration = encoderConfiguration;
-		this.future1 = future1;	//on signals: meanPower
+		this.future1 = future1;	//on curves: meanPower
 		this.future2 = future2;
 		this.future3 = future3;
 		this.exerciseName = exerciseName;
@@ -830,12 +848,10 @@ public class EncoderCaptureCurve {
 
 public class EncoderCaptureCurveArray {
 	public ArrayList ecc;	//each of the EncoderCaptureCurve
-	public int curvesDone;	//starts at int 0. How many ecc have been calculated by R
 	public int curvesAccepted; //starts at int 0. How many ecc have been accepted (will be rows in treeview_encoder_capture_curves)
 	
 	public EncoderCaptureCurveArray() {
 		ecc = new ArrayList();
-		curvesDone = 0;
 		curvesAccepted = 0;
 	}
 	
@@ -845,12 +861,16 @@ public class EncoderCaptureCurveArray {
 public class EncoderBarsData {
 	public double MeanSpeed;
 	public double MaxSpeed;
+	public double MeanForce;
+	public double MaxForce;
 	public double MeanPower;
 	public double PeakPower;
 	
-	public EncoderBarsData(double meanSpeed, double maxSpeed, double meanPower, double peakPower) {
+	public EncoderBarsData(double meanSpeed, double maxSpeed, double meanForce, double maxForce, double meanPower, double peakPower) {
 		this.MeanSpeed = meanSpeed;
 		this.MaxSpeed  = maxSpeed;
+		this.MeanForce = meanForce;
+		this.MaxForce  = maxForce;
 		this.MeanPower = meanPower;
 		this.PeakPower = peakPower;
 	}
@@ -860,6 +880,10 @@ public class EncoderBarsData {
 			return MeanSpeed;
 		else if(option == Constants.MaxSpeed)
 			return MaxSpeed;
+		else if(option == Constants.MeanForce)
+			return MeanForce;
+		else if(option == Constants.MaxForce)
+			return MaxForce;
 		else if(option == Constants.MeanPower)
 			return MeanPower;
 		else // option == Constants.PeakPower
@@ -885,8 +909,16 @@ public class EncoderConfiguration {
 	public double D;	//external disc or pulley
 	public int anglePush;
 	public int angleWeight;
-	public int inertia;
+	
+	public int inertiaMachine; //this is the inertia without the disc
+	
 	public int gearedDown;	//demultiplication
+	
+	public int inertiaTotal; //this is the inertia used by R
+	public int extraWeightN; //how much extra weights (inertia)
+	public int extraWeightGrams; //weight of each extra weight (inertia)
+	public double extraWeightLength; //length from center to center (cm) (inertia)
+
 
 	public string textDefault = Catalog.GetString("Linear encoder attached to a barbell.") + "\n" + 
 		Catalog.GetString("Also common gym tests like jumps or chin-ups.");
@@ -908,8 +940,12 @@ public class EncoderConfiguration {
 		D = -1;
 		anglePush = -1;
 		angleWeight = -1;
-		inertia = -1;
+		inertiaMachine = -1;
 		gearedDown = 1;
+		inertiaTotal = -1;
+		extraWeightN = 0;
+		extraWeightGrams = 0;
+		extraWeightLength = 1;
 	}
 
 	// note: if this changes, change also in:
@@ -924,6 +960,7 @@ public class EncoderConfiguration {
 		has_inertia = false;
 		gearedDown = 1;
 
+		// ---- LINEAR ----
 		if(name == Constants.EncoderConfigurationNames.LINEAR) {
 			type = Constants.EncoderType.LINEAR;
 			position = 0;
@@ -1025,6 +1062,7 @@ public class EncoderConfiguration {
 			has_angle_push = true;
 			has_angle_weight = true;
 		}
+		// ---- ROTARY FRICTION ----
 		else if(name == Constants.EncoderConfigurationNames.ROTARYFRICTIONSIDE) {
 			type = Constants.EncoderType.ROTARYFRICTION;
 			position = 0;
@@ -1042,9 +1080,16 @@ public class EncoderConfiguration {
 			has_d = true;
 			has_D = true;
 		}
-		else if(name == Constants.EncoderConfigurationNames.ROTARYFRICTIONSIDEINERTIAL) {
+		else if(name == Constants.EncoderConfigurationNames.WEIGHTEDMOVPULLEYROTARYFRICTION) {
 			type = Constants.EncoderType.ROTARYFRICTION;
 			position = 2;
+			image = Constants.FileNameEncoderFrictionWithMovPulley;
+			code = "Rotary friction - moving pulley";
+			text = Catalog.GetString("Rotary friction encoder on weighted moving pulley.");
+		}
+		else if(name == Constants.EncoderConfigurationNames.ROTARYFRICTIONSIDEINERTIAL) {
+			type = Constants.EncoderType.ROTARYFRICTION;
+			position = 3;
 			image = Constants.FileNameEncoderFrictionSideInertial;
 			code = "Rotary friction - inertial machine side";
 			text = Catalog.GetString("Rotary friction encoder on inertial machine side.") + "\n" +
@@ -1057,7 +1102,7 @@ public class EncoderConfiguration {
 		}
 		else if(name == Constants.EncoderConfigurationNames.ROTARYFRICTIONAXISINERTIAL) {
 			type = Constants.EncoderType.ROTARYFRICTION;
-			position = 3;
+			position = 4;
 			image = Constants.FileNameEncoderFrictionAxisInertial;
 			code = "Rotary friction axis - inertial machine axis";
 			text = Catalog.GetString("Rotary friction encoder on inertial machine axis.") + "\n" +
@@ -1067,13 +1112,63 @@ public class EncoderConfiguration {
 			has_d = true;
 			has_inertia = true;
 		}
-		else if(name == Constants.EncoderConfigurationNames.WEIGHTEDMOVPULLEYROTARYFRICTION) {
+		else if(name == Constants.EncoderConfigurationNames.ROTARYFRICTIONSIDEINERTIALLATERAL) {
 			type = Constants.EncoderType.ROTARYFRICTION;
-			position = 4;
-			image = Constants.FileNameEncoderFrictionWithMovPulley;
-			code = "Rotary friction - moving pulley";
-			text = Catalog.GetString("Rotary friction encoder on weighted moving pulley.");
+			position = 5;
+			image = Constants.FileNameEncoderFrictionSideInertialLateral;
+			code = "Rotary friction - inertial machine side - lateral movement";
+			text = Catalog.GetString("Rotary friction encoder on inertial machine when person is moving laterally.") + "\n" +
+				"*" + Catalog.GetString("Start capture with the string completely unwrapped.") + "*" + "\n" +
+				Catalog.GetString("On inertial machines, 'd' means the average diameter where the pull-push string is rolled");
+
+			has_d = true;
+			has_D = true;
+			has_inertia = true;
 		}
+		else if(name == Constants.EncoderConfigurationNames.ROTARYFRICTIONAXISINERTIALLATERAL) {
+			type = Constants.EncoderType.ROTARYFRICTION;
+			position = 6;
+			image = Constants.FileNameEncoderFrictionAxisInertialLateral;
+			code = "Rotary friction - inertial machine axis - lateral movement";
+			text = Catalog.GetString("Rotary friction encoder on inertial machine when person is moving laterally.") + "\n" +
+				"*" + Catalog.GetString("Start capture with the string completely unwrapped.") + "*" + "\n" +
+				Catalog.GetString("On inertial machines, 'd' means the average diameter where the pull-push string is rolled");
+
+			has_d = true;
+			has_inertia = true;
+		}
+		else if(name == Constants.EncoderConfigurationNames.ROTARYFRICTIONSIDEINERTIALMOVPULLEY) {
+			type = Constants.EncoderType.ROTARYFRICTION;
+			position = 7;
+			image = Constants.FileNameEncoderFrictionSideInertialMovPulley;
+			code = "Rotary friction - inertial machine side geared up";
+			text = Catalog.GetString("Rotary friction encoder on inertial machine geared up.") + "\n" +
+				"*" + Catalog.GetString("Person has to start fully extended (on the toes).") + "*" + "\n" +
+				Catalog.GetString("On inertial machines, 'd' means the average diameter where the pull-push string is rolled") + "\n" + 
+				Catalog.GetString("Inertial machine rolls twice faster than body."); 
+
+			has_d = true;
+			has_D = true;
+			has_inertia = true;
+			
+			gearedDown = -2; //gearedDown is not used in inertial machines. It's hardcoded
+		}
+		else if(name == Constants.EncoderConfigurationNames.ROTARYFRICTIONAXISINERTIALMOVPULLEY) {
+			type = Constants.EncoderType.ROTARYFRICTION;
+			position = 8;
+			image = Constants.FileNameEncoderFrictionAxisInertialMovPulley;
+			code = "Rotary friction - inertial machine axis geared up";
+			text = Catalog.GetString("Rotary friction encoder on inertial machine geared up.") + "\n" +
+				"*" + Catalog.GetString("Person has to start fully extended (on the toes).") + "*" + "\n" +
+				Catalog.GetString("On inertial machines, 'd' means the average diameter where the pull-push string is rolled") + "\n" + 
+				Catalog.GetString("Inertial machine rolls twice faster than body."); 
+
+			has_d = true;
+			has_inertia = true;
+			
+			gearedDown = -2; //gearedDown is not used in inertial machines. It's hardcoded
+		}
+		// ---- ROTARY AXIS ----
 		else if(name == Constants.EncoderConfigurationNames.ROTARYAXIS) {
 			type = Constants.EncoderType.ROTARYAXIS;
 			position = 0;
@@ -1083,9 +1178,19 @@ public class EncoderConfiguration {
 
 			has_D = true;
 		}
-		else if(name == Constants.EncoderConfigurationNames.ROTARYAXISINERTIAL) {
+		else if(name == Constants.EncoderConfigurationNames.WEIGHTEDMOVPULLEYROTARYAXIS) {
 			type = Constants.EncoderType.ROTARYAXIS;
 			position = 1;
+			image = Constants.FileNameEncoderAxisWithMovPulley;
+			code = "Rotary axis - moving pulley";
+			text = Catalog.GetString("Rotary axis encoder on weighted moving pulley.")
+				+ " " + Catalog.GetString("Mass is geared down by 2."); 
+			
+			gearedDown = 2;
+		}
+		else if(name == Constants.EncoderConfigurationNames.ROTARYAXISINERTIAL) {
+			type = Constants.EncoderType.ROTARYAXIS;
+			position = 2;
 			image = Constants.FileNameEncoderAxisInertial;
 			code = "Rotary axis - inertial machine";
 			text = Catalog.GetString("Rotary axis encoder on inertial machine.") + "\n" +
@@ -1095,46 +1200,118 @@ public class EncoderConfiguration {
 			has_d = true;
 			has_inertia = true;
 		}
-		else if(name == Constants.EncoderConfigurationNames.WEIGHTEDMOVPULLEYROTARYAXIS) {
+		else if(name == Constants.EncoderConfigurationNames.ROTARYAXISINERTIALLATERAL) {
 			type = Constants.EncoderType.ROTARYAXIS;
-			position = 2;
-			image = Constants.FileNameEncoderAxisWithMovPulley;
-			code = "Rotary axis - moving pulley";
-			text = Catalog.GetString("Rotary axis encoder on weighted moving pulley.")
-				+ " " + Catalog.GetString("Mass is geared down by 2."); 
+			position = 3;
+			image = Constants.FileNameEncoderAxisInertialLateral;
+			code = "Rotary axis - inertial machine - lateral movement";
+			text = Catalog.GetString("Rotary axis encoder on inertial machine when person is moving laterally.") + "\n" +
+				"*" + Catalog.GetString("Start capture with the string completely unwrapped.") + "*" + "\n" +
+				Catalog.GetString("On inertial machines, 'd' means the average diameter where the pull-push string is rolled");
+
+			has_d = true;
+			has_inertia = true;
+		}
+		else if(name == Constants.EncoderConfigurationNames.ROTARYAXISINERTIALMOVPULLEY) {
+			type = Constants.EncoderType.ROTARYAXIS;
+			position = 4;
+			image = Constants.FileNameEncoderAxisInertialMovPulley;
+			code = "Rotary axis - inertial machine geared up";
+			text = Catalog.GetString("Rotary axis encoder on inertial machine geared up.") + "\n" +
+				"*" + Catalog.GetString("Person has to start fully extended (on the toes).") + "*" + "\n" +
+				Catalog.GetString("On inertial machines, 'd' means the average diameter where the pull-push string is rolled") + "\n" + 
+				Catalog.GetString("Inertial machine rolls twice faster than body."); 
+
+			has_d = true;
+			has_inertia = true;
 			
-			gearedDown = 2;
+			gearedDown = -2; //gearedDown is not used in inertial machines. It's hardcoded
 		}
 	}
 
-	public void FromSQL (string [] strFull) {
+	public void ReadParamsFromSQL (string [] strFull) 
+	{
 		//adds other params
 		this.d = 	   Convert.ToDouble(Util.ChangeDecimalSeparator(strFull[1]));
 		this.D = 	   Convert.ToDouble(Util.ChangeDecimalSeparator(strFull[2]));
 		this.anglePush =   Convert.ToInt32(strFull[3]);
 		this.angleWeight = Convert.ToInt32(strFull[4]);
-		this.inertia = 	   Convert.ToInt32(strFull[5]);
+		this.inertiaMachine = 	Convert.ToInt32(strFull[5]);
 		this.gearedDown =  Convert.ToInt32(strFull[6]);
+	
+		//this params started at 1.5.1
+		if(strFull.Length > 7) {
+			this.inertiaTotal = 	Convert.ToInt32(strFull[7]);
+			this.extraWeightN = 	Convert.ToInt32(strFull[8]);
+			this.extraWeightGrams = Convert.ToInt32(strFull[9]);
+			this.extraWeightLength = Convert.ToDouble(Util.ChangeDecimalSeparator(strFull[10]));
+		} else {
+			this.inertiaTotal = 	inertiaMachine;
+			this.extraWeightN = 	0;
+			this.extraWeightGrams = 0;
+			this.extraWeightLength = 1;
+		}
+	}
+
+	//called on capture, recalculate, load
+	public void SQLUpdate()
+	{
+		SqlitePreferences.Update("encoderConfiguration", this.ToStringOutput(Outputs.SQL), false);
+	}
+
+	public enum Outputs { ROPTIONS, RCSV, SQL} 
+	
+	public string ToStringOutput(Outputs o) 
+	{
+		//for R and SQL		
+		string str_d = Util.ConvertToPoint(d);
+		string str_D = Util.ConvertToPoint(D);
+		
+		string sep = "";
+
+		if(o == Outputs.ROPTIONS) {
+			sep = "\n";
+			return 
+				"#name" + sep + 	name + sep + 
+				"#str_d" + sep + 	str_d + sep + 
+				"#str_D" + sep + 	str_D + sep + 
+				"#anglePush" + sep + 	anglePush.ToString() + sep + 
+				"#angleWeight" + sep + 	angleWeight.ToString() + sep +
+				"#inertiaTotal" + sep + inertiaTotal.ToString() + sep + 
+				"#gearedDown" + sep + 	gearedDown.ToString()
+				;
+		}
+		else if (o == Outputs.RCSV) { //not single curve
+			sep = ",";
+			//do not need inertiaMachine, extraWeightN, extraWeightGrams, extraWeightLength (unneded for the R calculations)
+			return 
+				name + sep + 
+				str_d + sep + 
+				str_D + sep + 
+				anglePush.ToString() + sep + 
+				angleWeight.ToString() + sep +
+				inertiaTotal.ToString() + sep + 
+				gearedDown.ToString()
+				;
+		}
+		else { //(o == Outputs.SQL) 
+			sep = ":";
+			return 
+				name + sep + 
+				str_d + sep + 
+				str_D + sep + 
+				anglePush.ToString() + sep + 
+				angleWeight.ToString() + sep +
+				inertiaMachine.ToString() + sep + 
+				gearedDown.ToString() + sep + 
+				inertiaTotal.ToString() + sep + 
+				extraWeightN.ToString() + sep + 
+				extraWeightGrams.ToString() + sep +
+				extraWeightLength.ToString()
+				;
+		}
 	}
 	
-	//decimalPointForR: ensure decimal is point in order to work in R
-	public string ToString(string sep, bool decimalPointForR) {
-		string str_d = "";
-		string str_D = "";
-		if(decimalPointForR) {
-			str_d = Util.ConvertToPoint(d);
-			str_D = Util.ConvertToPoint(D);
-		} else {
-			str_d = d.ToString();
-			str_D = D.ToString();
-		}
-
-		return 
-			name + sep + str_d + sep + str_D + sep + 
-			anglePush.ToString() + sep + angleWeight.ToString() + sep +
-			inertia.ToString() + sep + gearedDown.ToString();
-	}
-
 	//just to show on a treeview	
 	public string ToStringPretty() {
 		string sep = "; ";
@@ -1156,8 +1333,8 @@ public class EncoderConfiguration {
 			str_angleWeight = sep + "weight angle=" + angleWeight.ToString();
 
 		string str_inertia = "";
-		if(inertia != -1)
-			str_inertia = sep + "inertia=" + inertia.ToString();
+		if(has_inertia && inertiaTotal != -1)
+			str_inertia = sep + "inertia total=" + inertiaTotal.ToString();
 
 		string str_gearedDown = "";
 		if(gearedDown != 1)	//1 is the default
