@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -41,7 +41,7 @@ public class RunExecute : EventExecute
 	protected enum runPhases {
 		PRE_RUNNING, PLATFORM_INI_YES_TIME, PLATFORM_INI_NO_TIME, RUNNING, PLATFORM_END
 	}
-	protected runPhases runPhase;
+	protected static runPhases runPhase;
 		
 	protected bool checkDoubleContact;
 	protected int checkDoubleContactTime;
@@ -98,7 +98,7 @@ public class RunExecute : EventExecute
 	
 	public override void SimulateInitValues(Random randSent)
 	{
-		Log.WriteLine("From execute/run.cs");
+		LogB.Information("From execute/run.cs");
 
 		rand = randSent; //we send the random, because if we create here, the values will be the same for each nbew instance
 		simulated = true;
@@ -113,7 +113,7 @@ public class RunExecute : EventExecute
 	
 	public override void Manage()
 	{
-		Log.WriteLine("MANAGE!!!!");
+		LogB.Debug("MANAGE!!!!");
 
 		//boolean to know if chronopic has been disconnected	
 		chronopicDisconnected = false;
@@ -123,7 +123,7 @@ public class RunExecute : EventExecute
 		else
 			platformState = chronopicInitialValue(cp);
 		
-		Log.WriteLine("MANAGE(b)!!!!");
+		LogB.Debug("MANAGE(b)!!!!");
 
 		//you can start ON or OFF the platform, 
 		//we record always de TF (or time between we abandonate the platform since we arrive)
@@ -176,12 +176,12 @@ public class RunExecute : EventExecute
 		cancel = false;
 		totallyCancelled = false;
 
-		Log.WriteLine("MANAGE(2)!!!!");
 		//start thread
 		thread = new Thread(new ThreadStart(waitEvent));
 		GLib.Idle.Add (new GLib.IdleHandler (PulseGTK));
+			
+		LogB.ThreadStart(); 
 		thread.Start(); 
-		Log.WriteLine("MANAGE(3)!!!!");
 	}
 	
 	protected override void waitEvent ()
@@ -204,7 +204,7 @@ public class RunExecute : EventExecute
 			
 			//if (ok) {
 			if (ok && !cancel) {
-				//Log.WriteLine("timestamp:" + timestamp);
+				//LogB.Information("timestamp:" + timestamp);
 				if (platformState == Chronopic.Plataforma.ON && loggedState == States.OFF) {
 					//has arrived
 					loggedState = States.ON;
@@ -272,6 +272,8 @@ public class RunExecute : EventExecute
 							success = true;
 
 						if(success) {
+							runPhase = runPhases.PLATFORM_END;
+
 							//add the first contact time if PLATFORM_INI_YES_TIME
 							if(timestampFirstContact > 0)
 								timestamp += timestampFirstContact;
@@ -288,8 +290,6 @@ public class RunExecute : EventExecute
 									3
 									);  
 							needUpdateEventProgressBar = true;
-
-							runPhase = runPhases.PLATFORM_END;
 						}
 					}
 				}
@@ -338,7 +338,7 @@ public class RunExecute : EventExecute
 	}
 	
 	protected override void updateTimeProgressBar() {
-		/* 5 situations:
+		/* 4 situations:
 		 *   1- if we start out and have not arrived to platform, it should be a pulse with no time value on label:
 		 *		case runPhases.PRE_RUNNING
 		 *   2-  if we are on the platform, it should be a pulse
@@ -351,8 +351,13 @@ public class RunExecute : EventExecute
 		 *   3- if we leave the platform, it should be a pulse with timerCount on label:
 		 *		case runPhases.RUNNING
 		 *   4- if we arrive (finish), it should be a pulse with chronopic time on label:
-		 *		case runPhases.PLATFORM_END
+		 *		case runPhases.PLATFORM_END.
+		 *		Don't update time label here because later it will be overrided with the good data from Chronopic
+		 *		and sometimes can happen in different order, and then bad data (timerCount) will be shown on label at the end of test
 		 */
+			
+		if(runPhase == runPhases.PLATFORM_END) //see comment above
+			return;
 		
 		double myTimeValue = 0;
 		switch (runPhase) {
@@ -368,10 +373,6 @@ public class RunExecute : EventExecute
 			case runPhases.RUNNING:
 				myTimeValue = timerCount; //show time from the timerCount
 				break;
-			case runPhases.PLATFORM_END:
-				myTimeValue = timerCount; //show time from the timerCount
-				//but chronojump.cs will update info soon with chronopic value
-				break;
 		}
 				
 		
@@ -385,7 +386,7 @@ public class RunExecute : EventExecute
 
 	protected override void write()
 	{
-		Log.WriteLine(string.Format("TIME: {0}", time.ToString()));
+		LogB.Information(string.Format("TIME: {0}", time.ToString()));
 		
 		/*
 		string myStringPush =   Catalog.GetString("Last run") + ": " + RunnerName + " " + 
@@ -659,10 +660,11 @@ public class RunIntervalExecute : RunExecute
 								//has arrived, limited by tracks
 								if(tracks >= limitAsDouble) 
 								{
+									runPhase = runPhases.PLATFORM_END;
+
 									//finished
 									writeRunInterval(false); //tempTable = false
 									success = true;
-									runPhase = runPhases.PLATFORM_END;
 								}
 								//progressBarEventOrTimePreExecution(
 								updateProgressBar= new UpdateProgressBar (
@@ -743,6 +745,8 @@ public class RunIntervalExecute : RunExecute
 		} while ( ! success && ! cancel && ! finish );
 
 		if (finish) {
+			runPhase = runPhases.PLATFORM_END;
+
 			//write();
 			//write only if there's a run at minimum
 			if(Util.GetNumberOfJumps(intervalTimesString, false) >= 1) {
@@ -753,8 +757,6 @@ public class RunIntervalExecute : RunExecute
 				//cancel a run if clicked finish before any events done, or ended by time without events
 				cancel = true;
 			}
-
-			runPhase = runPhases.PLATFORM_END;
 		}
 		if(cancel || finish) {
 			//event will be raised, and managed in chronojump.cs
@@ -799,7 +801,7 @@ public class RunIntervalExecute : RunExecute
 	}
 	
 	protected override void updateTimeProgressBar() {
-		/* 5 situations:
+		/* 4 situations:
 		 *   1- if we start out and have not arrived to platform, it should be a pulse with no time value on label:
 		 *		case runPhases.PRE_RUNNING
 		 *   2-  if we are on the platform, it should be a pulse
@@ -813,8 +815,13 @@ public class RunIntervalExecute : RunExecute
 		 *		case runPhases.RUNNING
 		 *   4- if we arrive (finish), it should be a pulse with chronopic time on label:
 		 *		case runPhases.PLATFORM_END
+		 *		Don't update time label here because later it will be overrided with the good data from Chronopic
+		 *		and sometimes can happen in different order, and then bad data (timerCount) will be shown on label at the end of test
 		 */
 		
+		if(runPhase == runPhases.PLATFORM_END) //see comment above
+			return;
+		
 		double myTimeValue = 0;
 		bool percentageMode = true; //false is activity mode
 		switch (runPhase) {
@@ -834,11 +841,6 @@ public class RunIntervalExecute : RunExecute
 				percentageMode = !tracksLimited;
 				myTimeValue = timerCount; //show time from the timerCount
 				break;
-			case runPhases.PLATFORM_END:
-				percentageMode = !tracksLimited;
-				myTimeValue = timerCount; //show time from the timerCount
-				//but chronojump.cs will update info soon with chronopic value
-				break;
 		}
 			
 		if(! finish) 
@@ -876,7 +878,13 @@ public class RunIntervalExecute : RunExecute
 						//run limited by time that first subRun has arrived later than maximum for the whole run,
 						//and DeleteLastSubEvent returns "-" as a mark
 						if(intervalTimesString[0] == '-') {
-							new DialogMessage(Constants.MessageTypes.WARNING, Catalog.GetString("Run will not be recorded, 1st track is out of time"));
+							//this dialog can make crash the software because the non-gui part calls it
+							//new DialogMessage(Constants.MessageTypes.WARNING, 
+							//		Catalog.GetString("Run will not be recorded, 1st track is out of time"));
+
+							feedbackMessage = Catalog.GetString("Run will not be recorded. Out of time.");
+							needShowFeedbackMessage = true; 
+							LogB.Information("Run will not be recorded, 1st track is out of time");
 	
 							//mark for not having problems with cancelled
 							cancel = true;
@@ -886,7 +894,7 @@ public class RunIntervalExecute : RunExecute
 							//end this piece of code
 							return;
 						} else {
-							Log.WriteLine("Deleted one event out of time");
+							LogB.Information("Deleted one event out of time");
 							eventPassed = Util.EventPassedFromMaxTime(intervalTimesString, limitAsDouble);
 						}
 					}
