@@ -92,6 +92,14 @@ public partial class ChronoJumpWindow
 						cells[15], cells[16], cells[17] //meanForce, maxSForce maxForceT
 						));
 
+		}
+		//if last repetition is eccentric (there's no concentric movement after than that)
+		//then delete that curve
+		if(encoderCaptureCurves.Count > 0) {
+			EncoderCurve curve = (EncoderCurve) encoderCaptureCurves[encoderCaptureCurves.Count -1];
+			if(Convert.ToDouble(curve.Height) < 0) //it's 'e'
+				encoderCaptureCurves = Util.RemoveLastArrayElement(encoderCaptureCurves);
+
 		}
 
 		encoderCaptureListStore = new Gtk.ListStore (typeof (EncoderCurve));
@@ -415,6 +423,11 @@ public partial class ChronoJumpWindow
 			else { // if(eccon == "ecS")
 				iterPre = iter; //to point at the "e" curve
 				iterOk = encoderCaptureListStore.IterNext (ref iter);
+
+				//this fixes when there's a 'e' but not a 'c' in last repetition
+				if(! iterOk)
+					break;
+
 				EncoderCurve curve2 = (EncoderCurve) encoderCaptureListStore.GetValue (iter, 0);
 
 				LogB.Information("msCentral, start, end" + msCentral.ToString() + " " + curve.Start + " " + 
@@ -526,8 +539,11 @@ public partial class ChronoJumpWindow
 					//cells[3]: massBody
 					//cells[4]: massExtra
 
-					totalMass = Convert.ToDouble(cells[3]) * getExercisePercentBodyWeightFromName (exerciseName) / 100.0
-						+ Convert.ToDouble(cells[4]);
+					totalMass = Convert.ToDouble(Util.ChangeDecimalSeparator(cells[3])) * 
+						getExercisePercentBodyWeightFromName (exerciseName) / 100.0
+						+ Convert.ToDouble(Util.ChangeDecimalSeparator(cells[4]));
+					
+					LogB.Debug("totalMass:" + totalMass.ToString());
 				}
 
 				encoderAnalyzeCurves.Add (new EncoderCurve (
@@ -535,7 +551,7 @@ public partial class ChronoJumpWindow
 							cells[1],	//seriesName 
 							exerciseName,
 							cells[21],	//laterality
-							Convert.ToDouble(cells[4]),
+							Convert.ToDouble(Util.ChangeDecimalSeparator(cells[4])),
 							totalMass,
 							cells[5], cells[6], cells[7], 
 							cells[8], cells[9], cells[10], 
@@ -877,6 +893,7 @@ public partial class ChronoJumpWindow
 	private void RenderDisplacedWeight (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
 	{
 		EncoderCurve curve = (EncoderCurve) model.GetValue (iter, 0);
+		
 		(cell as Gtk.CellRendererText).Text = 
 			String.Format(UtilGtk.TVNumPrint(curve.DisplacedWeight.ToString(),3,0),Convert.ToInt32(curve.DisplacedWeight));
 	}
@@ -1018,15 +1035,37 @@ public partial class ChronoJumpWindow
 	private void RenderMeanForce (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
 	{
 		EncoderCurve curve = (EncoderCurve) model.GetValue (iter, 0);
+		string myColor = assignColor(
+				Convert.ToDouble(curve.MeanForce),
+				repetitiveConditionsWin.EncoderMeanForceHigher, 
+				repetitiveConditionsWin.EncoderMeanForceLower, 
+				repetitiveConditionsWin.EncoderMeanForceHigherValue,
+				repetitiveConditionsWin.EncoderMeanForceLowerValue);
+		if(myColor != "")
+			(cell as Gtk.CellRendererText).Foreground = myColor;
+		else
+			(cell as Gtk.CellRendererText).Foreground = null;	//will show default color
+
 		(cell as Gtk.CellRendererText).Text = 
-			String.Format(UtilGtk.TVNumPrint(curve.MeanPower,7,1),Convert.ToDouble(curve.MeanForce));
+			String.Format(UtilGtk.TVNumPrint(curve.MeanForce,7,1),Convert.ToDouble(curve.MeanForce));
 	}
 
 	private void RenderMaxForce (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
 	{
 		EncoderCurve curve = (EncoderCurve) model.GetValue (iter, 0);
+		string myColor = assignColor(
+				Convert.ToDouble(curve.MaxForce),
+				repetitiveConditionsWin.EncoderMaxForceHigher, 
+				repetitiveConditionsWin.EncoderMaxForceLower, 
+				repetitiveConditionsWin.EncoderMaxForceHigherValue,
+				repetitiveConditionsWin.EncoderMaxForceLowerValue);
+		if(myColor != "")
+			(cell as Gtk.CellRendererText).Foreground = myColor;
+		else
+			(cell as Gtk.CellRendererText).Foreground = null;	//will show default color
+
 		(cell as Gtk.CellRendererText).Text = 
-			String.Format(UtilGtk.TVNumPrint(curve.MeanPower,7,1),Convert.ToDouble(curve.MaxForce));
+			String.Format(UtilGtk.TVNumPrint(curve.MaxForce,7,1),Convert.ToDouble(curve.MaxForce));
 	}
 	
 	private void RenderMaxForceT (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
