@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -26,22 +26,30 @@ using Glade;
 using GLib; //for Value
 using System.Text; //StringBuilder
 using System.Collections; //ArrayList
-
+using Mono.Unix;
 
 public class ErrorWindow
 {
 	[Widget] Gtk.Window error_window;
 	[Widget] Gtk.Label label1;
+	[Widget] Gtk.Button button_abort; //used only when there are problems because USB has been removed on the middle of the test
 	[Widget] Gtk.Button button_accept;
+	[Widget] Gtk.Box hbox_send_log;
 	[Widget] Gtk.Button button_open_database_folder;
 	[Widget] Gtk.Button button_open_docs_folder;
+	[Widget] Gtk.Image image_send_log_no;
+	[Widget] Gtk.Image image_send_log_yes;
+	[Widget] Gtk.Entry entry_send_log;
+	[Widget] Gtk.TextView textview_comments;
+	[Widget] Gtk.Button button_send_log;
+	[Widget] Gtk.Label label_send_log_message;
 
 	string table;
 	static ErrorWindow ErrorWindowBox;
 	
 	public ErrorWindow (string text1)
 	{
-		Console.WriteLine("At error window2");
+		LogB.Information("At error window2");
 		Glade.XML gladeXML;
 		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "error_window", "chronojump");
 		gladeXML.Autoconnect(this);
@@ -55,12 +63,13 @@ public class ErrorWindow
 
 	static public ErrorWindow Show (string text1)
 	{
-		Console.WriteLine("At error window");
+		LogB.Information("At error window");
 		if (ErrorWindowBox == null) {
 			ErrorWindowBox = new ErrorWindow(text1);
 		}
 		
 		//hidden always excepted when called to be shown (see below)
+		ErrorWindowBox.hbox_send_log.Hide();
 		ErrorWindowBox.button_open_database_folder.Hide();
 
 		ErrorWindowBox.error_window.Show();
@@ -78,7 +87,54 @@ public class ErrorWindow
 		//need this for continue execution on chronojump startup. See src/chronojump.cs
 		button_accept.Click();
 	}
-	
+
+	string emailStored;
+	public void Show_send_log() 
+	{
+		emailStored = SqlitePreferences.Select("email");
+		if(emailStored != null && emailStored != "" && emailStored != "0")
+			entry_send_log.Text = emailStored;
+		
+		hbox_send_log.Show();
+		
+		//button_send_log.Label = "Disabled";
+		//button_send_log.Sensitive = false;
+	}
+	private void on_button_send_log_clicked (object o, EventArgs args)
+	{
+		string email = entry_send_log.Text.ToString();
+		//email can be validated with Util.IsValidEmail(string)
+		//or other methods, but maybe there's no need of complexity now 
+
+		//1st save email on sqlite
+		if(email != null && email != "" && email != "0" && email != emailStored)
+			SqlitePreferences.Update("email", email, false);
+
+		//2nd if there are comments, add them at the beginning of the file
+		string comments = textview_comments.Buffer.Text;
+		
+		//2nd send Json
+		Json js = new Json();
+		bool success = js.PostCrashLog(email, comments);
+		
+		if(success) {
+			button_send_log.Label = Catalog.GetString("Thanks");
+			button_send_log.Sensitive = false;
+
+			image_send_log_yes.Show();
+			image_send_log_no.Hide();
+			LogB.Information(js.ResultMessage);
+		} else {
+			button_send_log.Label = Catalog.GetString("Try again");
+			
+			image_send_log_yes.Hide();
+			image_send_log_no.Show();
+			LogB.Error(js.ResultMessage);
+		}
+
+		label_send_log_message.Text = js.ResultMessage;
+	}
+
 	public void Show_button_open_database_folder () {
 		button_open_database_folder.Show();
 	}
@@ -103,7 +159,7 @@ public class ErrorWindow
 	}
 	private void on_button_open_docs_folder_clicked (object o, EventArgs args)
 	{
-		Log.WriteLine("Opening docs at: " + Path.GetFullPath(Util.GetManualDir())); 
+		LogB.Information("Opening docs at: " + Path.GetFullPath(Util.GetManualDir())); 
 		try {
 			System.Diagnostics.Process.Start(Path.GetFullPath(Util.GetManualDir())); 
 		} catch {
@@ -113,6 +169,13 @@ public class ErrorWindow
 					);
 		}
 	}
+	
+	public void Show_button_abort () {
+		button_abort.Show();
+	}
+	private void on_button_abort_clicked (object o, EventArgs args) {
+
+	}
 
 	public void Button_accept_label (string str) {
 		button_accept.Label = str;
@@ -128,6 +191,15 @@ public class ErrorWindow
 		get { return button_accept; }
 	} 	
 
+	public Button Button_abort {
+		get { return button_abort; }
+	} 	
+	
+	public void HideAndNull() {
+		ErrorWindowBox.error_window.Hide();
+		ErrorWindowBox = null;
+	}
+
 	~ErrorWindow() {}
 	
 }
