@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -83,6 +83,7 @@ public partial class ChronoJumpWindow
 	//for the color change in the background of the cell label
 	[Widget] Gtk.EventBox event_execute_eventbox_jump_simple_tc;
 	[Widget] Gtk.EventBox event_execute_eventbox_jump_simple_tf;
+	//[Widget] Gtk.EventBox event_execute_eventbox_jump_reactive_height;
 	[Widget] Gtk.EventBox event_execute_eventbox_jump_reactive_tc;
 	[Widget] Gtk.EventBox event_execute_eventbox_jump_reactive_tf;
 	//[Widget] Gtk.EventBox event_execute_eventbox_jump_reactive_tf_tc;
@@ -104,10 +105,12 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Label event_execute_label_jump_simple_height_person;
 	[Widget] Gtk.Label event_execute_label_jump_simple_height_session;
 
-	[Widget] Gtk.Label event_execute_label_jump_reactive_tc_now;
-	[Widget] Gtk.Label event_execute_label_jump_reactive_tc_avg;
+	[Widget] Gtk.Label event_execute_label_jump_reactive_height_now;
+	[Widget] Gtk.Label event_execute_label_jump_reactive_height_avg;
 	[Widget] Gtk.Label event_execute_label_jump_reactive_tf_now;
 	[Widget] Gtk.Label event_execute_label_jump_reactive_tf_avg;
+	[Widget] Gtk.Label event_execute_label_jump_reactive_tc_now;
+	[Widget] Gtk.Label event_execute_label_jump_reactive_tc_avg;
 	[Widget] Gtk.Label event_execute_label_jump_reactive_tf_tc_now;
 	[Widget] Gtk.Label event_execute_label_jump_reactive_tf_tc_avg;
 
@@ -130,6 +133,8 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Label event_execute_label_reaction_time_person;
 	[Widget] Gtk.Label event_execute_label_reaction_time_session;
 
+	[Widget] Gtk.Image event_execute_image_jump_reactive_height_good;
+	[Widget] Gtk.Image event_execute_image_jump_reactive_height_bad;
 	[Widget] Gtk.Image event_execute_image_jump_reactive_tf_good;
 	[Widget] Gtk.Image event_execute_image_jump_reactive_tf_bad;
 	[Widget] Gtk.Image event_execute_image_jump_reactive_tc_good;
@@ -260,6 +265,7 @@ public partial class ChronoJumpWindow
 	
 		event_execute_eventbox_jump_simple_tc.ModifyBg(Gtk.StateType.Normal, UtilGtk.RED_PLOTS);
 		event_execute_eventbox_jump_simple_tf.ModifyBg(Gtk.StateType.Normal, UtilGtk.BLUE_PLOTS);
+		//event_execute_eventbox_jump_reactive_height.ModifyBg(Gtk.StateType.Normal, UtilGtk.RED_PLOTS);
 		event_execute_eventbox_jump_reactive_tc.ModifyBg(Gtk.StateType.Normal, UtilGtk.RED_PLOTS);
 		event_execute_eventbox_jump_reactive_tf.ModifyBg(Gtk.StateType.Normal, UtilGtk.BLUE_PLOTS);
 		event_execute_eventbox_run_simple_time.ModifyBg(Gtk.StateType.Normal, UtilGtk.RED_PLOTS);
@@ -296,12 +302,14 @@ public partial class ChronoJumpWindow
 	private void eventExecutePutNonStandardIcons() {
 		Pixbuf pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "stock_bell_green.png");
+		event_execute_image_jump_reactive_height_good.Pixbuf = pixbuf;
 		event_execute_image_jump_reactive_tf_good.Pixbuf = pixbuf;
 		event_execute_image_jump_reactive_tc_good.Pixbuf = pixbuf;
 		event_execute_image_jump_reactive_tf_tc_good.Pixbuf = pixbuf;
 		event_execute_image_run_interval_time_good.Pixbuf = pixbuf;
 		
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "stock_bell_red.png");
+		event_execute_image_jump_reactive_height_bad.Pixbuf = pixbuf;
 		event_execute_image_jump_reactive_tf_bad.Pixbuf = pixbuf;
 		event_execute_image_jump_reactive_tc_bad.Pixbuf = pixbuf;
 		event_execute_image_jump_reactive_tf_tc_bad.Pixbuf = pixbuf;
@@ -309,6 +317,8 @@ public partial class ChronoJumpWindow
 	}
 
 	private void eventExecuteHideImages() {
+		event_execute_image_jump_reactive_height_good.Hide();
+		event_execute_image_jump_reactive_height_bad.Hide();
 		event_execute_image_jump_reactive_tf_good.Hide();
 		event_execute_image_jump_reactive_tf_bad.Hide();
 		event_execute_image_jump_reactive_tc_good.Hide();
@@ -375,10 +385,12 @@ public partial class ChronoJumpWindow
 		event_execute_table_jump_reactive_values.Show();
 
 		//initializeLabels
-		event_execute_label_jump_reactive_tc_now.Text = "";
-		event_execute_label_jump_reactive_tc_avg.Text = "";
+		event_execute_label_jump_reactive_height_now.Text = "";
+		event_execute_label_jump_reactive_height_avg.Text = "";
 		event_execute_label_jump_reactive_tf_now.Text = "";
 		event_execute_label_jump_reactive_tf_avg.Text = "";
+		event_execute_label_jump_reactive_tc_now.Text = "";
+		event_execute_label_jump_reactive_tc_avg.Text = "";
 		event_execute_label_jump_reactive_tf_tc_now.Text = "";
 		event_execute_label_jump_reactive_tf_tc_avg.Text = "";
 
@@ -628,7 +640,7 @@ public partial class ChronoJumpWindow
 		if(eventGraphConfigureWin == null)
 			eventGraphConfigureWin = EventGraphConfigureWindow.Show(false);
 
-Log.WriteLine("Preparing reactive A");
+		LogB.Debug("Preparing reactive A");
 
 		//search MAX
 		double maxValue = 0;
@@ -1231,6 +1243,7 @@ Log.WriteLine("Preparing reactive A");
 		int ancho=drawingarea.Allocation.Width;
 		int alto=drawingarea.Allocation.Height;
 
+		double lastHeight = Convert.ToDouble(Util.GetHeightInCentimeters(lastTv.ToString()));
 		
 		UtilGtk.ErasePaint(event_execute_drawingarea, event_execute_pixmap);
 		
@@ -1314,12 +1327,16 @@ Log.WriteLine("Preparing reactive A");
 			plotSimulatedMessageIfNeededAtCenter(ancho, alto);
 			
 			//bells & images
+			event_execute_image_jump_reactive_height_good.Hide();
+			event_execute_image_jump_reactive_height_bad.Hide();
 			event_execute_image_jump_reactive_tf_good.Hide();
 			event_execute_image_jump_reactive_tf_bad.Hide();
 			event_execute_image_jump_reactive_tc_good.Hide();
 			event_execute_image_jump_reactive_tc_bad.Hide();
 			event_execute_image_jump_reactive_tf_tc_good.Hide();
 			event_execute_image_jump_reactive_tf_tc_bad.Hide();
+			bool showHeightGood = false;
+			bool showHeightBad = false;
 			bool showTfGood = false;
 			bool showTfBad = false;
 			bool showTcGood = false;
@@ -1335,6 +1352,11 @@ Log.WriteLine("Preparing reactive A");
 					showTfTcBad = true;
 			}
 				
+			if(repetitiveConditionsWin.HeightGreater && lastHeight > repetitiveConditionsWin.HeightGreaterValue) 
+				showHeightGood = true;
+			if(repetitiveConditionsWin.HeightLower && lastHeight < repetitiveConditionsWin.HeightLowerValue) 
+				showHeightBad = true;
+
 			if(repetitiveConditionsWin.TfGreater && lastTv > repetitiveConditionsWin.TfGreaterValue) 
 				showTfGood = true;
 			if(repetitiveConditionsWin.TfLower && lastTv < repetitiveConditionsWin.TfLowerValue) 
@@ -1351,11 +1373,15 @@ Log.WriteLine("Preparing reactive A");
 				showTfTcGood = true;
 
 
-			if(showTfGood || showTcGood || showTfTcGood)
+			if(showHeightGood || showTfGood || showTcGood || showTfTcGood)
 				Util.PlaySound(Constants.SoundTypes.GOOD, volumeOn);
-			if(showTfBad || showTcBad || showTfTcBad)
+			if(showHeightBad || showTfBad || showTcBad || showTfTcBad)
 				Util.PlaySound(Constants.SoundTypes.BAD, volumeOn);
 
+			if(showHeightGood)
+				event_execute_image_jump_reactive_height_good.Show();
+			if(showHeightBad)
+				event_execute_image_jump_reactive_height_bad.Show();
 			if(showTfGood)
 				event_execute_image_jump_reactive_tf_good.Show();
 			if(showTfBad)
@@ -1374,15 +1400,24 @@ Log.WriteLine("Preparing reactive A");
 		 * these Log.writeLines are useful to don't "get the thread dead"
 		 * without them , sometimes drawingarea is not painted
 		 */
-		event_execute_label_jump_reactive_tc_now.Text = "<b>" + Util.TrimDecimals(lastTc.ToString(), preferences.digitsNumber) + "</b>";
-		event_execute_label_jump_reactive_tc_now.UseMarkup = true; 
-		
-		event_execute_label_jump_reactive_tc_avg.Text = Util.TrimDecimals(avgTC.ToString(), preferences.digitsNumber);
 
+		//height
+		event_execute_label_jump_reactive_height_now.Text = "<b>" + Util.TrimDecimals(lastHeight.ToString(), preferences.digitsNumber) + "</b>";
+		event_execute_label_jump_reactive_height_now.UseMarkup = true; 
+		event_execute_label_jump_reactive_height_avg.Text = Util.TrimDecimals(
+				Util.GetHeightInCentimeters(avgTV.ToString()), preferences.digitsNumber);
+		
+		//TV
 		event_execute_label_jump_reactive_tf_now.Text = "<b>" + Util.TrimDecimals(lastTv.ToString(), preferences.digitsNumber) + "</b>";
 		event_execute_label_jump_reactive_tf_now.UseMarkup = true; 
-		
 		event_execute_label_jump_reactive_tf_avg.Text = Util.TrimDecimals(avgTV.ToString(), preferences.digitsNumber);
+		
+		//TC
+		event_execute_label_jump_reactive_tc_now.Text = "<b>" + Util.TrimDecimals(lastTc.ToString(), preferences.digitsNumber) + "</b>";
+		event_execute_label_jump_reactive_tc_now.UseMarkup = true; 
+		event_execute_label_jump_reactive_tc_avg.Text = Util.TrimDecimals(avgTC.ToString(), preferences.digitsNumber);
+
+		//TV / TC
 		if(lastTc > 0) {
 			event_execute_label_jump_reactive_tf_tc_now.Text = "<b>" + Util.TrimDecimals((lastTv/lastTc).ToString(), preferences.digitsNumber) + "</b>";
 			event_execute_label_jump_reactive_tf_tc_now.UseMarkup = true; 
@@ -1574,7 +1609,7 @@ Log.WriteLine("Preparing reactive A");
 		if(time < 0)
 			time = 0;
 
-		//Console.WriteLine("   timestamp {0}, ancho {1}, x {2}, timeold{3}, xOld{4}", 
+		//LogB.Information("   timestamp {0}, ancho {1}, x {2}, timeold{3}, xOld{4}", 
 		//timestamp, ancho, Util.TrimDecimals(x,1), timeOld, Util.TrimDecimals(xOld,1));
 
 		return ( ancho * ( (timeOld + time) / timeTotal) ) -event_execute_rightMargin;
@@ -1611,7 +1646,7 @@ Log.WriteLine("Preparing reactive A");
 			if(timeTotal4 > timeTotal)
 				timeTotal = timeTotal4;
 		}
-		Console.WriteLine("total time: {0}", timeTotal);
+		LogB.Information("total time: {0}" + timeTotal);
 
 
 		/*
@@ -1637,22 +1672,22 @@ Log.WriteLine("Preparing reactive A");
 		//if(maxValue - minValue <= 0) 
 		//	return;
 
-		Console.Write(" paint0 ");
+		LogB.Debug(" paint0 ");
 		
 		if(event_execute_eventType == Constants.RunAnalysisName)
 			paintMultiChronopicRunAPhotocell (ancho, cp1StartedIn, cp1InStr, cp1OutStr, yCp1Out +10, yCp1Out);
 		else
 			paintMultiChronopicDefault (ancho, cp1StartedIn, cp1InStr, cp1OutStr, timeTotal, yCp1Out +10, yCp1Out);
 
-		Console.Write(" paint1 ");
+		LogB.Debug(" paint1 ");
 		paintMultiChronopicDefault (ancho, cp2StartedIn, cp2InStr, cp2OutStr, timeTotal, yCp2Out +10, yCp2Out);
-		Console.Write(" paint2 ");
+		LogB.Debug(" paint2 ");
 		paintMultiChronopicDefault (ancho, cp3StartedIn, cp3InStr, cp3OutStr, timeTotal, yCp3Out +10, yCp3Out);
-		Console.Write(" paint3 ");
+		LogB.Debug(" paint3 ");
 		paintMultiChronopicDefault (ancho, cp4StartedIn, cp4InStr, cp4OutStr, timeTotal, yCp4Out +10, yCp4Out);
-		Console.Write(" paint4 ");
+		LogB.Debug(" paint4 ");
 
-		Console.Write(" paint done ");
+		LogB.Information(" paint done ");
 	}
 
 	private void paintMultiChronopicDefault (int ancho, bool cpStartedIn, string cpInStr, string cpOutStr, double timeTotal, int h1, int h2) 
@@ -1695,7 +1730,7 @@ Log.WriteLine("Preparing reactive A");
 		double xOld = 0;
 		bool lastCpIsStart = true;
 
-		Console.WriteLine("\n(A) cpInStr:*{0}*, cpOutStr:*{1}*", cpInStr, cpOutStr);
+		LogB.Information("(A) cpInStr:*" + cpInStr + "*, cpOutStr:*" + cpOutStr + "*");
 
 		for(int i=0; i < ticks; i++) { 
 			if(cpStart.Length > i) {
@@ -1730,14 +1765,14 @@ Log.WriteLine("Preparing reactive A");
 		   following code allows to paint line also on other chronopics
 		   in order to show all updated four cps after any cp change
 		   */
-		Console.WriteLine("(C)");
+		LogB.Debug("(C)");
 		if(timeOld < timeTotal) { //this cp didn't received last event
 			if(lastCpIsStart)
 				event_execute_pixmap.DrawLine(penStartDiscont, Convert.ToInt32(xOld), heightStart, Convert.ToInt32(ancho-event_execute_rightMargin), heightStart);
 			else
 				event_execute_pixmap.DrawLine(penEndDiscont, Convert.ToInt32(xOld), heightEnd, Convert.ToInt32(ancho-event_execute_rightMargin), heightEnd);
 		}
-		Console.WriteLine("(D)");
+		LogB.Debug("(D)");
 	}
 
 	private void paintMultiChronopicRunAPhotocell (int ancho, bool cpStartedIn, string cpInStr, string cpOutStr, int h1, int h2) 
