@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -116,7 +116,7 @@ public class EditJumpWindow : EditEventWindow
 		else
 			label_weight_units.Text = "Kg";
 
-		Log.WriteLine(string.Format("-------------{0}", personWeight));
+		LogB.Information(string.Format("-------------{0}", personWeight));
 	}
 
 	protected override string [] findTypes(Event myEvent) {
@@ -429,7 +429,7 @@ public class EditJumpWindow : EditEventWindow
 			double newPersonWeight = SqlitePersonSession.SelectAttribute(false, personID, mySessionID, Constants.Weight); 
 			//jumpPercentWeightForNewPerson = jumpWeightInKg * 100 / newPersonWeight; 
 			jumpPercentWeightForNewPerson = Util.WeightFromKgToPercent(jumpWeightInKg, newPersonWeight); 
-			Log.WriteLine(string.Format("oldPW: {0}, jWinKg {1}, newPW{2}, jWin%NewP{3}",
+			LogB.Information(string.Format("oldPW: {0}, jWinKg {1}, newPW{2}, jWin%NewP{3}",
 					oldPersonWeight, jumpWeightInKg, newPersonWeight, jumpPercentWeightForNewPerson));
 		}
 
@@ -632,7 +632,7 @@ public class RepairJumpRjWindow
 	
 	static public RepairJumpRjWindow Show (Gtk.Window parent, JumpRj myJump, int pDN)
 	{
-		//Log.WriteLine(myJump);
+		//LogB.Information(myJump);
 		if (RepairJumpRjWindowBox == null) {
 			RepairJumpRjWindowBox = new RepairJumpRjWindow (parent, myJump, pDN);
 		}
@@ -1031,7 +1031,7 @@ partial class ChronoJumpWindow
 	//jumps_rj
 	double extra_window_jumps_rj_limited = 10;
 	bool extra_window_jumps_rj_jumpsLimited;
-	string extra_window_jumps_rj_option = "Kg";
+	string extra_window_jumps_rj_option = "%";
 	double extra_window_jumps_rj_weight = 20;
 	double extra_window_jumps_rj_fall = 20;
 	
@@ -1567,7 +1567,7 @@ public class JumpsMoreWindow : EventMoreWindow
 		
 		//delete from typesTranslated
 		string row = Util.FindOnArray(':',0, -1, selectedEventName, typesTranslated);
-		Log.WriteLine("row " + row);
+		LogB.Information("row " + row);
 		typesTranslated = Util.DeleteString(typesTranslated, row);
 	}
 
