@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -622,7 +622,7 @@ public class RepairRunIntervalWindow
 	
 	static public RepairRunIntervalWindow Show (Gtk.Window parent, RunInterval myRun, int pDN)
 	{
-		//Log.WriteLine(myRun);
+		//LogB.Information(myRun);
 		if (RepairRunIntervalWindowBox == null) {
 			RepairRunIntervalWindowBox = new RepairRunIntervalWindow (parent, myRun, pDN);
 		}
@@ -1315,7 +1315,7 @@ public class RunsMoreWindow : EventMoreWindow
 		
 		//delete from typesTranslated
 		string row = Util.FindOnArray(':',0, -1, selectedEventName, typesTranslated);
-		Log.WriteLine("row " + row);
+		LogB.Information("row " + row);
 		typesTranslated = Util.DeleteString(typesTranslated, row);
 	}
 
