@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -148,6 +148,8 @@ public partial class ChronoJumpWindow {
 		else {
 			notebook_stats_sup.CurrentPage = 0;
 
+			combo_stats_stat_type.Changed -= new EventHandler (on_combo_stats_stat_type_changed);
+
 			bool sensitive = false;
 			bool showType = false;
 			if(testPage == 0) {
@@ -165,6 +167,8 @@ public partial class ChronoJumpWindow {
 				UtilGtk.ComboUpdate(combo_stats_stat_type, comboStatsTypeOptions[3]);
 			else if(testPage == 3)
 				UtilGtk.ComboUpdate(combo_stats_stat_type, comboStatsTypeOptions[4]);
+			
+			combo_stats_stat_type.Changed += new EventHandler (on_combo_stats_stat_type_changed);
 
 			combo_stats_stat_type.Active = 0;
 			combo_stats_stat_type.Sensitive = sensitive;
@@ -540,7 +544,7 @@ public partial class ChronoJumpWindow {
 				myStatType.MarkSelected(myText);
 				myStatType.CreateOrUpdateAVGAndSD();
 			} catch {
-				Log.WriteLine("Do later!!");
+				LogB.Warning("Do later!!");
 			}
 		}
 	}
@@ -558,6 +562,7 @@ public partial class ChronoJumpWindow {
 	
 	private void updateComboStats() {
 		string [] nullOptions = { "-" };
+		
 		if(UtilGtk.ComboGetActive(combo_stats_stat_type) == Constants.TypeSessionSummary ) 
 		{
 			UtilGtk.ComboUpdate(combo_stats_stat_subtype, nullOptions, "");
@@ -571,7 +576,10 @@ public partial class ChronoJumpWindow {
 			UtilGtk.ComboUpdate(combo_stats_stat_subtype, nullOptions, "");
 			combo_stats_stat_subtype.Sensitive = false;
 			
-			ArrayList persons = SqlitePersonSession.SelectCurrentSessionPersons(currentSession.UniqueID);
+			ArrayList persons = SqlitePersonSession.SelectCurrentSessionPersons(
+					currentSession.UniqueID,
+					false); //means: do not returnPersonAndPSlist
+
 			string [] personsStrings = new String[persons.Count];
 			int i=0;
 			foreach (Person person in persons) 
@@ -583,7 +591,10 @@ public partial class ChronoJumpWindow {
 		} 
 		else if (UtilGtk.ComboGetActive(combo_stats_stat_type) == Constants.TypeJumpsSimple ) 
 		{
+			combo_stats_stat_subtype.Changed -= new EventHandler (on_combo_stats_stat_subtype_changed);
 			UtilGtk.ComboUpdate(combo_stats_stat_subtype, comboStatsSubTypeSimpleOptions, "");
+			combo_stats_stat_subtype.Changed += new EventHandler (on_combo_stats_stat_subtype_changed);
+
 			combo_stats_stat_subtype.Sensitive = true;
 			combo_stats_stat_subtype.Active = 0;
 			
@@ -596,7 +607,10 @@ public partial class ChronoJumpWindow {
 		} 
 		else if (UtilGtk.ComboGetActive(combo_stats_stat_type) == Constants.TypeJumpsSimpleWithTC ) 
 		{
+			combo_stats_stat_subtype.Changed -= new EventHandler (on_combo_stats_stat_subtype_changed);
 			UtilGtk.ComboUpdate(combo_stats_stat_subtype, comboStatsSubTypeWithTCOptions, "");
+			combo_stats_stat_subtype.Changed += new EventHandler (on_combo_stats_stat_subtype_changed);
+
 			combo_stats_stat_subtype.Sensitive = true;
 			combo_stats_stat_subtype.Active = 0;
 			
@@ -607,7 +621,10 @@ public partial class ChronoJumpWindow {
 		} 
 		else if (UtilGtk.ComboGetActive(combo_stats_stat_type) == Constants.TypeJumpsReactive ) 
 		{
+			combo_stats_stat_subtype.Changed -= new EventHandler (on_combo_stats_stat_subtype_changed);
 			UtilGtk.ComboUpdate(combo_stats_stat_subtype, comboStatsSubTypeReactiveOptions, "");
+			combo_stats_stat_subtype.Changed += new EventHandler (on_combo_stats_stat_subtype_changed);
+			
 			combo_stats_stat_subtype.Sensitive = true;
 			combo_stats_stat_subtype.Active = 0;
 			
@@ -618,7 +635,10 @@ public partial class ChronoJumpWindow {
 		}
 		else if (UtilGtk.ComboGetActive(combo_stats_stat_type) == Constants.TypeRunsSimple ) 
 		{
+			combo_stats_stat_subtype.Changed -= new EventHandler (on_combo_stats_stat_subtype_changed);
 			UtilGtk.ComboUpdate(combo_stats_stat_subtype, comboStatsSubTypeSimpleOptions, "");
+			combo_stats_stat_subtype.Changed += new EventHandler (on_combo_stats_stat_subtype_changed);
+			
 			combo_stats_stat_subtype.Sensitive = false;
 			combo_stats_stat_subtype.Active = 0;
 			
@@ -629,7 +649,10 @@ public partial class ChronoJumpWindow {
 		} 
 		else if (UtilGtk.ComboGetActive(combo_stats_stat_type) == Constants.TypeRunsIntervallic ) 
 		{
+			combo_stats_stat_subtype.Changed -= new EventHandler (on_combo_stats_stat_subtype_changed);
 			UtilGtk.ComboUpdate(combo_stats_stat_subtype, comboStatsSubTypeSimpleOptions, "");
+			combo_stats_stat_subtype.Changed += new EventHandler (on_combo_stats_stat_subtype_changed);
+			
 			combo_stats_stat_subtype.Sensitive = false;
 			combo_stats_stat_subtype.Active = 0;
 			
@@ -716,7 +739,8 @@ public partial class ChronoJumpWindow {
 							"CMJ"); //default value
 				combo_stats_stat_apply_to.Sensitive = false;
 			}
-		}  else if (UtilGtk.ComboGetActive(combo_stats_stat_type) == Constants.TypeJumpsSimpleWithTC ) 
+		}  
+		else if (UtilGtk.ComboGetActive(combo_stats_stat_type) == Constants.TypeJumpsSimpleWithTC ) 
 		{
 			UtilGtk.ComboUpdate(combo_stats_stat_apply_to, 
 				SqliteJumpType.SelectJumpTypes(false, Constants.AllJumpsName, "TC", true), ""); //only select name
@@ -792,7 +816,7 @@ public partial class ChronoJumpWindow {
 		if(blockFillingTreeview)
 			return false;
 		
-		Log.WriteLine("----------FILLING treeview stats---------------");
+		LogB.Information("----------FILLING treeview stats---------------");
 	
 		string statisticType = UtilGtk.ComboGetActive(combo_stats_stat_type);
 		string statisticSubType = UtilGtk.ComboGetActive(combo_stats_stat_subtype);
@@ -913,7 +937,7 @@ public partial class ChronoJumpWindow {
 				button_add_to_report.Sensitive = false;
 			}
 		} catch {
-			Log.WriteLine("Do markedRows stuff later");
+			LogB.Warning("Do markedRows stuff later");
 		}
 
 		//show enunciate of the stat in textview_enunciate
@@ -956,19 +980,19 @@ public partial class ChronoJumpWindow {
 
 	//changes the combo_select_checkboxes to "Selected" if any row in the treeview is checked or unchecked
 	private void on_fake_button_row_checked_clicked (object o, EventArgs args) {
-		Log.WriteLine("fakeButtonRowCheckedUnchecked in gui/stats.cs !!");
+		LogB.Information("fakeButtonRowCheckedUnchecked in gui/stats.cs !!");
 
 		combo_select_checkboxes.Active = UtilGtk.ComboMakeActive(comboCheckboxesOptions, Catalog.GetString("Selected"));
 	}
 	
 	private void on_fake_button_rows_selected_clicked (object o, EventArgs args) {
-		Log.WriteLine("fakeButtonRowsSelected in gui/stats.cs !!");
+		LogB.Information("fakeButtonRowsSelected in gui/stats.cs !!");
 		button_graph.Sensitive = true;
 		button_add_to_report.Sensitive = true;
 	}
 	
 	private void on_fake_button_no_rows_selected_clicked (object o, EventArgs args) {
-		Log.WriteLine("fakeButtonNoRowsSelected in gui/stats.cs !!");
+		LogB.Information("fakeButtonNoRowsSelected in gui/stats.cs !!");
 		button_graph.Sensitive = false;
 		button_add_to_report.Sensitive = false;
 
@@ -1130,7 +1154,7 @@ public partial class ChronoJumpWindow {
 
 	private void on_combo_stats_stat_type_changed(object o, EventArgs args) {
 		//update combo stats_subtype, there change the treeviewstats (with the combostats_subtype values changed)
-		
+	
 		updateComboStats();
 		
 		update_stats_widgets_sensitiveness();
@@ -1178,7 +1202,7 @@ public partial class ChronoJumpWindow {
 	{
 		if(o == (object) radiobutton_current_session) 
 		{
-			Log.WriteLine("current");
+			LogB.Information("current");
 			button_stats_select_sessions.Sensitive = false;
 
 			//single session can have all graph types
@@ -1197,7 +1221,7 @@ public partial class ChronoJumpWindow {
 		} 
 		else if (o == (object) radiobutton_selected_sessions ) 
 		{
-			Log.WriteLine("selected");
+			LogB.Information("selected");
 			button_stats_select_sessions.Sensitive = true;
 			
 			//multi session use only barplot and lines
@@ -1242,13 +1266,13 @@ public partial class ChronoJumpWindow {
 	}
 	
 	private void on_button_stats_select_sessions_clicked (object o, EventArgs args) {
-		Log.WriteLine("select sessions for stats");
+		LogB.Information("select sessions for stats");
 		sessionSelectStatsWin = SessionSelectStatsWindow.Show(app1, selectedSessions);
 		sessionSelectStatsWin.Button_accept.Clicked += new EventHandler(on_stats_select_sessions_accepted);
 	}
 	
 	private void on_stats_select_sessions_accepted (object o, EventArgs args) {
-		Log.WriteLine("select sessions for stats accepted");
+		LogB.Information("select sessions for stats accepted");
 		
 		if ((sessionSelectStatsWin.ArrayOfSelectedSessions[0]).ToString() != "-1") { 
 			//there are sessionsSelected, put them in selectedSessions ArrayList
@@ -1265,7 +1289,7 @@ public partial class ChronoJumpWindow {
 	}
 	
 	private void on_button_add_to_report_clicked (object o, EventArgs args) {
-		Log.WriteLine("add to report window");
+		LogB.Information("add to report window");
 
 		string statisticType = UtilGtk.ComboGetActive(combo_stats_stat_type);
 		string statisticSubType = UtilGtk.ComboGetActive(combo_stats_stat_subtype);
