@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2009   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -60,7 +60,7 @@ public partial class PersonSession {
 
 	//creation
 	//we know personID but not personSession.UniqueID
-	//this adds to database
+	//this adds to personSession77 table in database
 	public PersonSession(int personID, int sessionID,
 			double height, double weight, int sportID, 
 			int speciallityID, int practice, string comments, bool dbconOpened)
@@ -82,7 +82,7 @@ public partial class PersonSession {
 		int insertedID = this.InsertAtDB(dbconOpened, Constants.PersonSessionTable);
 		uniqueID = insertedID;
 
-		Log.WriteLine(this.ToString());
+		LogB.Information(this.ToString());
 	}
 	
 	public int InsertAtDB (bool dbconOpened, string tableName) {
