@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -96,7 +96,7 @@ public class Report : ExportSession
 		}
 
 		if(ShowCurrentSessionJumpers) {
-			myPersons = SqlitePersonSession.SelectCurrentSessionPersons(sessionID);
+			myPersonsAndPS = SqlitePersonSession.SelectCurrentSessionPersons(sessionID, true);
 		}
 		if(ShowSimpleJumps) {
 			myJumps= SqliteJump.SelectJumps(false, sessionID, -1, "", "");
