@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2009   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -55,7 +55,7 @@ public class Server
 	public static string Ping(bool doInsertion, string progName, string progVersion) {
 		try {
 			ChronojumpServer myServer = new ChronojumpServer();
-			Log.WriteLine(myServer.ConnectDatabase());
+			LogB.Information(myServer.ConnectDatabase());
 		
 			int evalSID = Convert.ToInt32(SqlitePreferences.Select("evaluatorServerID"));
 			string machineID = SqlitePreferences.Select("machineID");
@@ -68,10 +68,10 @@ public class Server
 			//is ok for uploadPerson to know if server is online
 			string versionAvailable = myServer.UploadPing(myPing, doInsertion);
 			
-			Log.WriteLine(myServer.DisConnectDatabase());
+			LogB.Information(myServer.DisConnectDatabase());
 			return versionAvailable;
 		} catch (Exception e){
-			Log.WriteLine("Server Connection "+e.Message);
+			LogB.Information("Server Connection", e.Message);
 			return Constants.ServerOffline;
 		}
 	}
@@ -120,7 +120,7 @@ public class Server
 	{
 		if(! thread.IsAlive) {
 			sessionUploadWin.UploadFinished();
-			Log.Write("dying");
+			LogB.Information("dying");
 			return false;
 		}
 
@@ -155,7 +155,7 @@ public class Server
 		}
 		
 		Thread.Sleep (50);
-		Log.Write(thread.ThreadState.ToString());
+		LogB.Debug(thread.ThreadState.ToString());
 		return true;
 	}
 	
@@ -165,7 +165,7 @@ public class Server
 
 		try {	
 			ChronojumpServer myServer = new ChronojumpServer();
-			Log.WriteLine(myServer.ConnectDatabase());
+			LogB.Information(myServer.ConnectDatabase());
 		
 			int state = (int) Constants.ServerSessionStates.UPLOADINGSESSION;
 			//create ServerSession based on Session currentSession
@@ -192,7 +192,9 @@ public class Server
 			string sportsSeparator = "";
 
 			//upload persons (updating also person.serverUniqueID locally)
-			ArrayList persons = SqlitePersonSession.SelectCurrentSessionPersons(serverSession.UniqueID); 
+			ArrayList persons = SqlitePersonSession.SelectCurrentSessionPersons(
+					serverSession.UniqueID,
+					false); //means: do not returnPersonAndPSlist
 			
 			Constants.UploadCodes uCode;
 			ArrayList notToUpload = SqlitePersonSessionNotUpload.SelectAll(currentSession.UniqueID);
@@ -220,7 +222,7 @@ public class Server
 					
 				//if sport is user defined, upload it
 				//and when upload the person, do it with new sportID
-				Sport sport = SqliteSport.Select(ps.SportID);
+				Sport sport = SqliteSport.Select(false, ps.SportID);
 				//but record old sport ID because locally will be a change in serverUniqueID
 				//(with slite update)
 				//but local sport has not to be changed
@@ -551,7 +553,7 @@ public class Server
 			//myServer.UpdateSession(currentSession.ServerUniqueID, (ServerSessionStates)  Constants.ServerSessionStates.DONE); 
 			myServer.UpdateSession(currentSession.ServerUniqueID, state); 
 
-			Log.WriteLine(myServer.DisConnectDatabase());
+			LogB.Information(myServer.DisConnectDatabase());
 		} catch {
 			//other thread updates the gui:
 			serverSessionError = true;
@@ -643,7 +645,7 @@ public class Server
 	public static void ServerUploadEvaluator () {
 		try {
 			ChronojumpServer myServer = new ChronojumpServer();
-			Log.WriteLine(myServer.ConnectDatabase());
+			LogB.Information(myServer.ConnectDatabase());
 			
 			ServerEvaluator myEval = SqliteServer.SelectEvaluator(1);
 
@@ -668,7 +670,7 @@ public class Server
 				new DialogMessage(Constants.MessageTypes.WARNING, 
 						string.Format(Catalog.GetString("Evaluator {0} has not been correctly uploaded. Maybe codes doesn't match."), evalSID));
 			
-			Log.WriteLine(myServer.DisConnectDatabase());
+			LogB.Information(myServer.DisConnectDatabase());
 		} catch {
 			new DialogMessage(Constants.MessageTypes.WARNING, Constants.ServerOffline);
 		}
