@@ -73,7 +73,7 @@ class Sqlite
 	/*
 	 * Important, change this if there's any update to database
 	 */
-	static string lastChronojumpDatabaseVersion = "1.22";
+	static string lastChronojumpDatabaseVersion = "1.23";
 
 	public Sqlite() {
 	}
@@ -92,15 +92,15 @@ class Sqlite
 	public static void Open()
 	{
 		try {
-			LogB.SQL("SQL ON");
+			LogB.SQLon();
 			dbcon.Open();
 		} catch {
 			LogB.SQL("-- catched --");
 
-			LogB.SQL("SQL OFF");
+			LogB.SQLoff();
 			dbcon.Close();
 			
-			LogB.SQL("SQL ON");
+			LogB.SQLon();
 			dbcon.Open();
 			
 			LogB.SQL("-- end of catched --");
@@ -108,7 +108,7 @@ class Sqlite
 	}
 	public static void Close()
 	{
-		LogB.SQL("SQL OFF");
+		LogB.SQLoff();
 		dbcon.Close();
 	}
 
@@ -1207,7 +1207,7 @@ class Sqlite
 
 				//delete all it's runs
 				Sqlite.Open();
-				dbcmd.CommandText = "Delete FROM " + Constants.RunIntervalTable +
+				dbcmd.CommandText = "DELETE FROM " + Constants.RunIntervalTable +
 					" WHERE type == 'RSA 8-4-R3-5'";
 				LogB.SQL(dbcmd.CommandText.ToString());
 				dbcmd.ExecuteNonQuery();
@@ -1479,7 +1479,7 @@ class Sqlite
 						es.signalOrCurve + "', '" + es.filename + "', '" +
 						es.url + "', " + es.time + ", " + es.minHeight + ", '" + es.description + "', '" + 
 						es.status + "', '" + es.videoURL + "', '" + 
-						econf.ToString(":", true) + "', '" + //in this conversion put this as default for all SQL rows
+						econf.ToStringOutput(EncoderConfiguration.Outputs.SQL) + "', '" + //in this conversion put this as default for all SQL rows.
 						es.future1 + "', '" + es.future2 + "', '" + es.future3 + "')";
 					LogB.SQL(dbcmd.CommandText.ToString());
 					dbcmd.ExecuteNonQuery();
@@ -1783,6 +1783,16 @@ class Sqlite
 
 				currentVersion = "1.22";
 			}
+			if(currentVersion == "1.22") {
+				LogB.SQL("Added encoder configuration");
+				
+				Sqlite.Open();
+				SqlitePreferences.Insert ("encoderConfiguration", new EncoderConfiguration().ToStringOutput(EncoderConfiguration.Outputs.SQL)); 
+				SqlitePreferences.Update ("databaseVersion", "1.23", true); 
+				Sqlite.Close();
+
+				currentVersion = "1.23";
+			}
 	
 		}
 
@@ -1927,6 +1937,7 @@ class Sqlite
 		SqliteExecuteAuto.addChronojumpProfileAndBilateral();
 		
 		//changes [from - to - desc]
+		//1.22 - 1.23 Converted DB to 1.23 Added encoder configuration
 		//1.21 - 1.22 Converted DB to 1.22 Encoder laterality in english again
 		//1.20 - 1.21 Converted DB to 1.21 Fixing loosing of encoder videoURL after recalculate
 		//1.19 - 1.20 Converted DB to 1.20 Preferences: added user email
@@ -2142,7 +2153,7 @@ class Sqlite
 
 		Sqlite.Open();
 		//dbcmd.CommandText = "Delete FROM tempJumpRj";
-		dbcmd.CommandText = "Delete FROM " + tableName;
+		dbcmd.CommandText = "DELETE FROM " + tableName;
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 		Sqlite.Close();
@@ -2792,7 +2803,7 @@ LogB.SQL("5" + tableName);
 			cond2 = cond2Pre + columnNameCondition2 + " == '" + searchValueCondition2 + "'"; 
 		}
 
-		dbcmd.CommandText = "Update " + tableName +
+		dbcmd.CommandText = "UPDATE " + tableName +
 			" SET " + columnName + " = '" + newValue + "'" +  
 			cond1 +
 			cond2
@@ -2809,7 +2820,7 @@ LogB.SQL("5" + tableName);
 		if( ! dbconOpened)
 			Sqlite.Open();
 
-		dbcmd.CommandText = "Delete FROM " + tableName +
+		dbcmd.CommandText = "DELETE FROM " + tableName +
 			" WHERE uniqueID == " + uniqueID.ToString();
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
@@ -2823,7 +2834,7 @@ LogB.SQL("5" + tableName);
 		if( ! dbconOpened)
 			Sqlite.Open();
 
-		dbcmd.CommandText = "Delete FROM " + tableName +
+		dbcmd.CommandText = "DELETE FROM " + tableName +
 			" WHERE " + fieldName + " == " + id;
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
@@ -2838,7 +2849,7 @@ LogB.SQL("5" + tableName);
 		if( ! dbconOpened)
 			Sqlite.Open();
 
-		dbcmd.CommandText = "Delete FROM " + tableName +
+		dbcmd.CommandText = "DELETE FROM " + tableName +
 			" WHERE name == '" + name + "'";
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
@@ -2852,7 +2863,7 @@ LogB.SQL("5" + tableName);
 		if( ! dbconOpened)
 			Sqlite.Open();
 
-		dbcmd.CommandText = "Delete FROM " + tableName +
+		dbcmd.CommandText = "DELETE FROM " + tableName +
 			" WHERE " + colName + " == " + id;
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
