@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 
@@ -45,17 +45,27 @@ class SqliteSpeciallity : Sqlite
 	{
 		conversionSubRateTotal = Speciallities.Length;
 		conversionSubRate = 0;
-		foreach(string myString in Speciallities) {
-			string [] strFull = myString.Split(new char[] {':'});
-			string sportName = strFull[0];
-			string speciallityEnglishName = strFull[1];
-			int sportID = SqliteSport.SelectID(sportName);
-			Insert(true, sportID, speciallityEnglishName);
-			conversionSubRate ++;
+
+		using(SqliteTransaction tr = dbcon.BeginTransaction())
+		{
+			using (SqliteCommand dbcmdTr = dbcon.CreateCommand())
+			{
+				dbcmdTr.Transaction = tr;
+	
+				foreach(string myString in Speciallities) {
+					string [] strFull = myString.Split(new char[] {':'});
+					string sportName = strFull[0];
+					string speciallityEnglishName = strFull[1];
+					int sportID = SqliteSport.SelectID(sportName);
+					Insert(true, dbcmdTr, sportID, speciallityEnglishName);
+					conversionSubRate ++;
+				}
+			}
+			tr.Commit();
 		}
 	}
 
-	public static int Insert(bool dbconOpened, int sportID, string speciallityName)
+	public static int Insert(bool dbconOpened, SqliteCommand mycmd, int sportID, string speciallityName)
 	{
 		if(! dbconOpened)
 			Sqlite.Open();
@@ -63,14 +73,15 @@ class SqliteSpeciallity : Sqlite
 		string myString = "INSERT INTO " + Constants.SpeciallityTable + 
 			" (uniqueID, sportID, name) VALUES (NULL, " + sportID + ", '" + speciallityName + "')"; 
 		
-		dbcmd.CommandText = myString;
-		dbcmd.ExecuteNonQuery();
+		mycmd.CommandText = myString;
+		LogB.SQL(mycmd.CommandText.ToString());
+		mycmd.ExecuteNonQuery();
 
 		//int myLast = dbcon.LastInsertRowId;
 		//http://stackoverflow.com/questions/4341178/getting-the-last-insert-id-with-sqlite-net-in-c
 		myString = @"select last_insert_rowid()";
-		dbcmd.CommandText = myString;
-		int myLast = Convert.ToInt32(dbcmd.ExecuteScalar()); // Need to type-cast since `ExecuteScalar` returns an object.
+		mycmd.CommandText = myString;
+		int myLast = Convert.ToInt32(mycmd.ExecuteScalar()); // Need to type-cast since `ExecuteScalar` returns an object.
 		
 		if(! dbconOpened)
 			Sqlite.Close();
@@ -78,16 +89,17 @@ class SqliteSpeciallity : Sqlite
 		return myLast;
 	}
 
-	public static string Select(int uniqueID)
+	public static string Select(bool dbconOpened, int uniqueID)
 	{
 		if(uniqueID == -1)
 			return "";
 
-		Sqlite.Open();
+		if(! dbconOpened)
+			Sqlite.Open();
 		
 		dbcmd.CommandText = "SELECT name FROM " + Constants.SpeciallityTable + " WHERE uniqueID == " + uniqueID;
 		
-		Log.WriteLine(dbcmd.CommandText.ToString());
+		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 
 		SqliteDataReader reader;
@@ -97,8 +109,10 @@ class SqliteSpeciallity : Sqlite
 		string speciallityName = reader[0].ToString(); //name
 	
 		reader.Close();
-		Sqlite.Close();
-		//return uniqueID + ":" + Catalog.GetString(speciallityName);
+		
+		if(! dbconOpened)
+			Sqlite.Close();
+		
 		return Catalog.GetString(speciallityName);
 	}
 	
@@ -118,7 +132,7 @@ class SqliteSpeciallity : Sqlite
 			whereString +
 			" ORDER BY uniqueID";
 		
-		Log.WriteLine(dbcmd.CommandText.ToString());
+		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 		reader = dbcmd.ExecuteReader();
 
