@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2014   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2015   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -31,7 +31,8 @@ public class TreeViewJumps : TreeViewEvent
 	protected string weightName = Catalog.GetString("Extra weight");
 	protected string fallName = Catalog.GetString("Fall") + "\n(cm)";
 	protected string heightName = Catalog.GetString("Height") + "\n(cm)";
-	protected string powerName = Catalog.GetString("Power") + "\n(" + Catalog.GetString("see Preferences") +")";
+	protected string powerName = Catalog.GetString("Power");
+	protected string stiffnessName = Catalog.GetString("Stiffness") + "\n(N/m)";
 	protected string initialSpeedName = Catalog.GetString("Initial Speed");
 	protected string angleName = Catalog.GetString("Angle");
 
@@ -68,7 +69,9 @@ public class TreeViewJumps : TreeViewEvent
 		string [] columnsStringPre = { jumperName, 
 			Catalog.GetString("TC") + "\n(s)", 
 			Catalog.GetString("TF") + "\n(s)", 
-			weightName, fallName }; //Note: if this changes, check the '5's in obtainColumnsString
+			weightName, fallName,
+			heightName
+	       	};
 
 		columnsString = obtainColumnsString(columnsStringPre);
 	
@@ -84,10 +87,11 @@ public class TreeViewJumps : TreeViewEvent
 
 	protected override int getColsNum() {
 		int i = columnsString.Length;
-		if (preferences.showHeight)  
-			i ++;
+		
 		if (preferences.showPower)  
 			i ++;
+		if (preferences.showStiffness)  
+			i ++;
 		if (preferences.showInitialSpeed) 
 			i ++;
 		if (preferences.showAngle) 
@@ -100,11 +104,12 @@ public class TreeViewJumps : TreeViewEvent
 	protected string [] obtainColumnsString(string [] columnsStringPre) 
 	{
 		//check long of new array
-		int i = 6; //columnsStringPre + uniqueID (at last)
-		if (preferences.showHeight)  
-			i ++;
+		int i = columnsStringPre.Length + 1; //columnsStringPre + uniqueID (at last)
+		
 		if (preferences.showPower)  
 			i ++;
+		if (preferences.showStiffness)  
+			i ++;
 		if (preferences.showInitialSpeed) 
 			i ++;
 		if (preferences.showAngle) 
@@ -114,7 +119,7 @@ public class TreeViewJumps : TreeViewEvent
 
 		//create new array
 		string [] columnsString = new String[i];
-		Array.Copy(columnsStringPre, columnsString, 5); //copy columnsStringPre
+		Array.Copy(columnsStringPre, columnsString, columnsStringPre.Length); //copy columnsStringPre
 
 	
 		if(preferences.metersSecondsPreferred)
@@ -124,11 +129,12 @@ public class TreeViewJumps : TreeViewEvent
 
 
 		//fill names
-		i = 5; //start at pos five end of columnsStringPre
-		if (preferences.showHeight)  
-			columnsString[i++] = heightName;
+		i = columnsStringPre.Length; //start at end of columnsStringPre
+		
 		if (preferences.showPower)  
 			columnsString[i++] = powerName;
+		if (preferences.showStiffness)  
+			columnsString[i++] = stiffnessName;
 		if (preferences.showInitialSpeed) 
 			columnsString[i++] = initialSpeedName;
 		if (preferences.showAngle) 
@@ -188,8 +194,7 @@ public class TreeViewJumps : TreeViewEvent
 		myData[count++] = Util.TrimDecimals(newJump.Weight.ToString(), pDN);
 
 		myData[count++] = Util.TrimDecimals(newJump.Fall.ToString(), pDN);
-		if (preferences.showHeight)  
-			myData[count++] = Util.TrimDecimals(Util.GetHeightInCentimeters(newJump.Tv.ToString()), pDN);
+		myData[count++] = Util.TrimDecimals(Util.GetHeightInCentimeters(newJump.Tv.ToString()), pDN);
 
 		
 
@@ -197,20 +202,24 @@ public class TreeViewJumps : TreeViewEvent
 			//takeoff has no tv. power should not be calculated
 			//calculate jumps with tf
 			if(newJump.Tv > 0) {	
+				//we calculate weightInKg again because can be changed in edit jump, and then treeview is no re-done
+				//but we do not calculate again person weight, because if it changes treeview is created again
+				weightInKg = Util.WeightFromPercentToKg(
+						Convert.ToDouble(newJump.Weight.ToString()),
+						personWeight);
+				
 				if(newJump.Tc > 0) 	//if it's Dj (has tf, and tc)
-					myData[count++] = Util.TrimDecimals(Util.GetDjPower(newJump.Tc, newJump.Tv, personWeight, newJump.Fall).ToString(), pDN);
-				else {			//it's a normal jump without tc
-					//we calculate weightInKg again because can be changed in edit jump, and then treeview is no re-done
-					//but we do not calculate again person weight, because if it changes treeview is created again
-					weightInKg = Util.WeightFromPercentToKg(
-							Convert.ToDouble(newJump.Weight.ToString()),
-							personWeight);
 					myData[count++] = Util.TrimDecimals(
-							Util.GetPower(newJump.Tv, personWeight, weightInKg).ToString(), pDN);
+							Util.GetDjPower(newJump.Tc, newJump.Tv, (personWeight + weightInKg), newJump.Fall).ToString(), 1);
+				else {			//it's a normal jump without tc
+					myData[count++] = Util.TrimDecimals(
+							Util.GetPower(newJump.Tv, personWeight, weightInKg).ToString(), 1);
 				}
 			} else
 				myData[count++] = "0";
 		}
+		if (preferences.showStiffness)
+			myData[count++] = Convert.ToInt32(newJump.Stiffness(personWeight, weightInKg)).ToString();
 		if (preferences.showInitialSpeed) 
 			myData[count++] = Util.TrimDecimals(Util.GetInitialSpeed(newJump.Tv.ToString(), preferences.metersSecondsPreferred), pDN);
 		if (preferences.showAngle) 
@@ -258,7 +267,9 @@ public class TreeViewJumpsRj : TreeViewJumps
 		string [] columnsStringPre = { jumperName, 
 			Catalog.GetString("TC") + "\n(s)", 
 			Catalog.GetString("TF") + "\n(s)", 
-			weightName, fallName };
+			weightName, fallName,
+			heightName
+	       	};
 		columnsString = obtainColumnsString(columnsStringPre);
 
 		eventIDColumn = columnsString.Length ; //column where the uniqueID of event will be (and will be hidded). 
@@ -278,6 +289,11 @@ public class TreeViewJumpsRj : TreeViewJumps
 		myJumpRj.Description = myStringOfData[9].ToString();
 		myJumpRj.Simulated = Convert.ToInt32(myStringOfData[18].ToString());
 		
+		personWeight = Convert.ToDouble(myStringOfData[19]);
+		weightInKg = Util.WeightFromPercentToKg(
+				Convert.ToDouble(myStringOfData[8]), 
+				personWeight);
+
 		//we create the jump with a weight of percent or kk
 		if(preferences.weightStatsPercent)
 			myJumpRj.Weight = Convert.ToDouble(myStringOfData[8].ToString());
@@ -310,10 +326,11 @@ public class TreeViewJumpsRj : TreeViewJumps
 		myData[count++] = Util.TrimDecimals(newJumpRj.Weight.ToString(), pDN);
 
 		myData[count++] = Util.TrimDecimals(newJumpRj.Fall.ToString(), pDN);
-		if (preferences.showHeight)  
-			myData[count++] = "";
+		myData[count++] = ""; //height
 		if (preferences.showPower)
 			myData[count++] = "";
+		if (preferences.showStiffness)
+			myData[count++] = "";
 		if (preferences.showInitialSpeed) 
 			myData[count++] = "";
 		if (preferences.showQIndex)
@@ -352,10 +369,33 @@ public class TreeViewJumpsRj : TreeViewJumps
 		myData[count++] = Util.TrimDecimals( thisTv, pDN );
 		myData[count++] = ""; 
 		myData[count++] = ""; 
-		if (preferences.showHeight)  
-			myData[count++] = Util.TrimDecimals(Util.GetHeightInCentimeters(thisTv), pDN);
-		if (preferences.showPower)
-			myData[count++] = "";
+		myData[count++] = Util.TrimDecimals(Util.GetHeightInCentimeters(thisTv), pDN);
+		if (preferences.showPower) {
+			double myFall;
+			if(lineCount == 0)
+				myFall = newJumpRj.Fall;
+			else
+				myFall = Convert.ToDouble(Util.GetHeightInCentimeters(myStringTv[lineCount -1]));
+			
+			if(Convert.ToDouble(thisTc) > 0)
+				myData[count++] = Util.TrimDecimals(
+						Util.GetDjPower(Convert.ToDouble(thisTc), Convert.ToDouble(thisTv), 
+							(personWeight + weightInKg), myFall).ToString(), 1);
+			else
+				myData[count++] = Util.TrimDecimals(
+						Util.GetPower(Convert.ToDouble(thisTv), personWeight, weightInKg).ToString(), 1);
+		}
+		if (preferences.showStiffness) {
+			//use directly Util.GetStiffness because we want to get from this specific subjump, not all the reactive jump.
+			if(Convert.ToDouble(thisTc) > 0) {
+				//show as integer in treeview, but let the other parts of the software (export) to show it as double
+				myData[count++] = Convert.ToInt32(
+						Util.GetStiffness(personWeight, weightInKg, Convert.ToDouble(thisTv), Convert.ToDouble(thisTc))
+						).ToString();
+			}
+			else
+				myData[count++] = ""; 
+		}
 		if (preferences.showInitialSpeed) 
 			myData[count++] = Util.TrimDecimals(Util.GetInitialSpeed(
 						thisTv, preferences.metersSecondsPreferred), pDN);
@@ -386,10 +426,11 @@ public class TreeViewJumpsRj : TreeViewJumps
 		myData[count++] = Util.TrimDecimals(Util.GetTotalTime(newJumpRj.TvString).ToString(), pDN);
 		myData[count++] = ""; //weight
 		myData[count++] = ""; //fall
-		if (preferences.showHeight)  
-			myData[count++] = ""; 
+		myData[count++] = ""; //height
 		if (preferences.showPower)
 			myData[count++] = "";
+		if (preferences.showStiffness)
+			myData[count++] = "";
 		if (preferences.showInitialSpeed) 
 			myData[count++] = ""; 
 		if (preferences.showQIndex || preferences.showDjIndex) 
@@ -430,13 +471,30 @@ public class TreeViewJumpsRj : TreeViewJumps
 
 		//this values are calculated using the AVG of the tcs or tvs, not as an avg of individual values
 
-		if (preferences.showHeight)  
-			myData[count++] = Util.TrimDecimals(
-					Util.GetHeightInCentimeters(
-						tvAVGDouble.ToString())
-					, pDN);
-		if (preferences.showPower)
+		myData[count++] = Util.TrimDecimals(
+				Util.GetHeightInCentimeters(
+					tvAVGDouble.ToString())
+				, pDN);
+		if (preferences.showPower) {
 			myData[count++] = "";
+
+			/* TODO:
+			 * it can be done using AVG values like the other AVG statistics,
+			 * but result will not be the same than making the avg of the different power values for each row
+			 * for this reason is best to first calculate the different values of each column and store separately
+			 * in order to calculate the total, AVG, SD using that data
+			 */
+		}
+		if (preferences.showStiffness) {
+			myData[count++] = "";
+
+			/* TODO:
+			 * it can be done using AVG values like the other AVG statistics,
+			 * but result will not be the same than making the avg of the different power values for each row
+			 * for this reason is best to first calculate the different values of each column and store separately
+			 * in order to calculate the total, AVG, SD using that data
+			 */
+		}
 		if (preferences.showInitialSpeed) 
 			myData[count++] = Util.TrimDecimals(
 					Util.GetInitialSpeed(
@@ -488,11 +546,11 @@ public class TreeViewJumpsRj : TreeViewJumps
 		
 		myData[count++] = ""; //weight
 		myData[count++] = ""; //fall
-
-		if (preferences.showHeight)  
-			myData[count++] = "";
+		myData[count++] = ""; //height
 		if (preferences.showPower)
 			myData[count++] = "";
+		if (preferences.showStiffness)
+			myData[count++] = "";
 		if (preferences.showInitialSpeed) 
 			myData[count++] = "";
 		if (preferences.showQIndex || preferences.showDjIndex) 
