@@ -319,6 +319,14 @@ public class Util
 		return myStringBuilder.ToString();
 	}
 
+	//use this!!!	
+	public static string RemoveChar(string s, char c) 
+	{
+		StringBuilder myStringBuilder = new StringBuilder(s);
+		myStringBuilder.Replace(c,' ');
+		return myStringBuilder.ToString();
+	}
+
 	public static string RemoveZeroOrMinus(string myString) 
 	{
 		if(myString == "0" || myString == "-")
@@ -866,6 +874,13 @@ public class Util
 			testType.ToString() + "-" + uniqueID.ToString() +
 			GetMultimediaExtension(Constants.MultimediaItems.VIDEO);
 	}
+	public static string GetVideoFileNameOnlyName (Constants.TestTypes testType, int uniqueID) {
+		return testType.ToString() + "-" + uniqueID.ToString() +
+			GetMultimediaExtension(Constants.MultimediaItems.VIDEO);
+	}
+	public static string GetVideoFileNameOnlyFolder (int sessionID) {
+		return GetVideoSessionDir(sessionID);
+	}
 	
 	public static string GetPhotoFileName (bool small, int uniqueID) {
 		return GetPhotosDir(small) + Path.DirectorySeparatorChar + uniqueID.ToString() +
@@ -982,7 +997,9 @@ public class Util
 			file.CopyTo(Path.Combine(target.FullName, file.Name));
 	}
 
-	public static bool FileDelete(string fileName) {
+	public static bool FileDelete(string fileName) 
+	{
+		LogB.Information("Checking if this filename exists: " + fileName);
 		try {
 			if(File.Exists(fileName)) {
 				LogB.Information("Deleting " + fileName + " ...");
@@ -1316,6 +1333,22 @@ public class Util
 
 		return false;
 	}
+	
+	public static bool FoundInStringArray(string [] a, string str) {
+		foreach (string str2 in a)
+			if(str2 == str)
+				return true;
+
+		return false;
+	}
+
+	public static ArrayList RemoveLastArrayElement(ArrayList a) {
+		if(a.Count > 0)
+			a.RemoveAt(a.Count - 1);
+
+		return a;
+	}
+
 
 	/*
 	//delete a row of and arraylist of string[] if the string[0] is the value coming from startsWith
