@@ -28,6 +28,8 @@ using System.Reflection; // Read Version
 //we do not use util.cs in mini because it has lot of calls to other files
 public class UtilAll
 {
+	static bool printedOS = false;
+
 	public static string ReadVersion() {
 		Version version = Assembly.GetExecutingAssembly().GetName().Version;
 		return version.ToString();
@@ -49,8 +51,19 @@ public class UtilAll
 	
 	public static string GetOS() {
 		OperatingSystem os = Environment.OSVersion;
-		string osString =  string.Format("{0}, {1}", os.Platform, os.Version);
-		LogB.Information("GetOS: " + osString);
+		string platform = os.Platform.ToString();
+
+		//detect a Mac that seems an Unix
+		if(platform == "Unix" && GetOSEnum() == OperatingSystems.MACOSX)
+			platform = "Unix (MacOSX)";
+
+		string osString =  string.Format("{0}, {1}", platform, os.Version);
+
+		if(! printedOS) {
+			LogB.Information("GetOS: " + osString);
+			printedOS = true;
+		}
+		
 		return osString;
 	}
 
