@@ -26,14 +26,10 @@ using System.Diagnostics; 	//for detect OS and for Process
 using System.IO; 		//for detect OS
 using Mono.Unix;
 
-using System.Linq;	//RDotNet
-using RDotNet;		//RDotNet
 
 //this class tries to be a space for methods that are used in different classes
 public class UtilEncoder
 {
-	public static bool CancelRScript;
-
 
 	/********** start of encoder paths ************/
 	
@@ -191,16 +187,6 @@ public class UtilEncoder
 	}
 	
 
-	/*
-	 * in RDotNet, graph.R is in memory, and call_graph.R is not called
-	 * if RDotNet is not working, then call_graph.R is called and this calls graph.R
-	 */
-
-	private static string getEncoderScriptCallGraph() {
-		return System.IO.Path.Combine(
-				Util.GetDataDir(), "encoder", Constants.EncoderScriptCallGraph);
-	}
-
 	public static string GetEncoderScriptGraph() {
 		return System.IO.Path.Combine(
 				Util.GetDataDir(), "encoder", Constants.EncoderScriptGraph);
@@ -233,7 +219,7 @@ public class UtilEncoder
 
 	
 	/*
-	 * DEPRECATED, now use always RDotNet
+	 * DEPRECATED, now use always RDotNet. Until 1.5.0 where RDotNet is not used anymore. Neither this Pyton method.
 	public static void RunEncoderCapturePython(string title, EncoderStruct es, string port) 
 	{
 		CancelRScript = false;
@@ -286,81 +272,6 @@ public class UtilEncoder
 	}
 	*/
 	
-	public static REngine RunEncoderCaptureCsharpInitializeR(REngine rengine, out Constants.Status RInitialized) 
-	{
-		LogB.Information("initializing rdotnet");
-		
-		//RDotNet.StartupParameter rsup = new RDotNet.StartupParameter();
-		//rsup.Interactive = false;
-		//rsup.Quiet = false;
-
-		rengine = REngine.CreateInstance("RDotNet");
-		
-		// From v1.5, REngine requires explicit initialization.
-		// You can set some parameters.
-
-		try {
-			//rengine.Initialize(rsup);
-			rengine.Initialize();
-		} catch {
-			RInitialized = Constants.Status.ERROR;
-			return rengine;
-		}
-		//Previous command, unfortunatelly localizes all GUI to english
-		//then call Catalog.Init again in order to see new windows localised		
-		//Catalog.Init("chronojump",System.IO.Path.Combine(Util.GetPrefixDir(),"share/locale"));
-
-		//load extrema method copied from EMD package
-		string utilRPath = GetEncoderScriptUtilR();
-		string graphRPath = GetEncoderScriptGraph();
-		
-		//On win32 R understands backlash as an escape character and 
-		//a file path uses Unix-like path separator '/'
-		if(UtilAll.IsWindows()) {
-			utilRPath = utilRPath.Replace("\\","/");
-			graphRPath = graphRPath.Replace("\\","/");
-		}
-		LogB.Information(utilRPath);
-		LogB.Information(graphRPath);
-		
-		try {
-			//load extrema
-			rengine.Evaluate("source('" + utilRPath + "')");
-			//load more stuff and call later using RDotNet
-			rengine.Evaluate("source('" + graphRPath + "')");
-		} catch {
-			RInitialized = Constants.Status.ERROR;
-			return rengine;
-		}
-
-		try {
-			// .NET Framework array to R vector.
-			NumericVector group1 = rengine.CreateNumericVector(new double[] { 30.02, 29.99, 30.11, 29.97, 30.01, 29.99 });
-			rengine.SetSymbol("group1", group1);
-			// Direct parsing from R script.
-			NumericVector group2 = rengine.Evaluate("group2 <- c(29.89, 29.93, 29.72, 29.98, 30.02, 29.98)").AsNumeric();
-
-			// Test difference of mean and get the P-value.
-			GenericVector testResult = rengine.Evaluate("t.test(group1, group2)").AsList();
-			double p = testResult["p.value"].AsNumeric().First();
-
-			//not using LogB because like with Console the format of numbers is displayed better
-			Console.WriteLine("Group1: [{0}]", string.Join(", ", group1));
-			Console.WriteLine("Group2: [{0}]", string.Join(", ", group2));
-			Console.WriteLine("P-value = {0:0.000}", p);
-		} catch {
-			RInitialized = Constants.Status.ERROR;
-			return rengine;
-		}
-
-		LogB.Information("initialized rdotnet");
-		
-		RInitialized = Constants.Status.OK;
-
-		return rengine;
-	}
-	
-	
 	public static EncoderGraphROptions PrepareEncoderGraphOptions(string title, EncoderStruct es, bool neuromuscularProfileDo, bool translate) 
 	{
 		string scriptUtilR = GetEncoderScriptUtilR();
@@ -374,6 +285,7 @@ public class UtilEncoder
 		string operatingSystem = "Linux";
 			
 		title = Util.RemoveBackSlash(title);
+		title = Util.RemoveChar(title, '\''); 
 		
 		if (UtilAll.IsWindows()) {
 			//convert accents to Unicode in order to be plotted correctly on R windows
@@ -403,6 +315,7 @@ public class UtilEncoder
 			foreach(string etw in Constants.EncoderTranslatedWords) {
 				temp = Util.ChangeChars(Catalog.GetString(etw), ";", ",");
 				temp = Util.RemoveNewLine(temp, true);
+				temp = Util.RemoveChar(temp, '#'); //needed to distinguish comments '#' than normal lines like the EncoderTranslatedWords
 				encoderTranslatedWordsOK[count++] = temp;
 			}
 		} else
@@ -419,234 +332,12 @@ public class UtilEncoder
 				scriptGraphR);
 	}
 
-	/*	
-	 *	Currently unused because this was called in main thread and when a pulse thread exists
-	 *	It should be without threading or in the GTK thread
-	 *	Now graph call is so fast with the call_graph.R
-	 *	then there's no need to add the complexity of calling RunEncoderGraphRDotNet outside the thread
-	 *	because the GTK thread has some interesting things that it does when it ends.
-	 *	We have enough speed now and we don't want to add more bugs
-	 *
-	public static bool RunEncoderGraph(REngine rengine, Constants.Status RInitialized,
-			string title, EncoderStruct es, bool neuromuscularProfileDo) 
-	{
-		if(RInitialized == Constants.Status.UNSTARTED)
-			RunEncoderCaptureCsharpInitializeR(rengine, out RInitialized);
-		
-		bool result = false;
-		if(RInitialized == Constants.Status.ERROR)
-			result = RunEncoderGraphNoRDotNet(title, es, neuromuscularProfileDo);
-		else if(RInitialized == Constants.Status.OK)
-			result = RunEncoderGraphRDotNet(rengine, title, es, neuromuscularProfileDo);
 
-		return result;
-	}
-
-	//this method uses RDotNet
-	public static bool RunEncoderGraphRDotNet(REngine rengine, string title, EncoderStruct es, bool neuromuscularProfileDo) 
-	{
-		//if RDotNet is ok, graph.R is already loaded
-		rengine.Evaluate("meanPower <- mean(c(2,3,4,5,6,7,8))");
-		double meanPower = rengine.GetSymbol("meanPower").AsNumeric().First();
-		Log.WriteLine(meanPower.ToString());
-		rengine.Evaluate("print(findPosInPaf(\"Power\", \"max\"))");
-
-		EncoderGraphROptions roptions = PrepareEncoderGraphOptions(title, es, neuromuscularProfileDo);
-		Log.WriteLine(roptions.ToString());	
-
-		//--------------------------------------------
-		//		Attention
-		//this code should be the same as call_graph.R
-		//--------------------------------------------
-
-		//TODO: pass roptions to RDotNet objects and then call graph.R
-		CharacterVector charVec;
-	
-		Log.WriteLine("-1-");	
-		string str_string = roptions.outputData2;
-		Log.WriteLine(str_string);
-		
-		charVec = rengine.CreateCharacterVector(new[] { str_string });
-		rengine.SetSymbol("OutputData2", charVec);
-	
-		Log.WriteLine("-2-");	
-		Log.WriteLine(roptions.specialData);	
-		Log.WriteLine("-3-");	
-		CharacterVector charVec2 = rengine.CreateCharacterVector(new[] { roptions.specialData });
-		rengine.SetSymbol("SpecialData", charVec2);
-		
-		Log.WriteLine(roptions.operatingSystem);	
-		charVec = rengine.CreateCharacterVector(new[] { roptions.operatingSystem });
-		rengine.SetSymbol("OperatingSystem", charVec);
-
-		return true;
-	}
-	*/
-
-
-
-	//here curve is sent compressed (string. eg: "0*5 1 0 -1*3 2")
-	public static void RunEncoderCaptureNoRDotNetSendCurve(Process p, double heightAtStart, string curveCompressed)
-	{
-		LogB.Debug("writing line 1 -->");
-		
-		string curveSend = "ps " + Util.ConvertToPoint(heightAtStart);
-		LogB.Debug("curveSend [heightAtStart]",curveSend);
-		p.StandardInput.WriteLine(curveSend);
-								
-		curveSend = curveCompressed;
-		
-		//TODO convert comma to point in this doubles
-
-		LogB.Debug("curveSend [displacement array]",curveSend);
-		p.StandardInput.WriteLine(curveSend); 	//this will send some lines because compressed data comes with '\n's
-		p.StandardInput.WriteLine("E");		//this will mean the 'E'nd of the curve. Then data can be uncompressed on R
-		
-		LogB.Debug("<-- writen line 1");
-	}
-	/* unused
-	 * here curve is sent uncompressed ([] double)
-	public static void RunEncoderCaptureNoRDotNetSendCurve(Process p, double heightAtStart, double [] d)
-	{
-		LogB.Debug("writing line 1 -->");
-		
-		string curveSend = "ps " + Util.ConvertToPoint(heightAtStart);
-		LogB.Debug("curveSend [heightAtStart]",curveSend);
-		p.StandardInput.WriteLine(curveSend);
-
-		//maybe this method falis when there's lots of data
-		curveSend = string.Join(" ", Array.ConvertAll(d, x => x.ToString()));
-		
-		//TODO convert comma to point in this doubles
-
-		LogB.Debug("curveSend [displacement array]",curveSend);
-		p.StandardInput.WriteLine(curveSend);
-		
-		LogB.Debug("<-- writen line 1");
-	}
-	*/
-	
-	public static void RunEncoderCaptureNoRDotNetSendEnd(Process p)
-	{
-		LogB.Debug("sending end line");
-		p.StandardInput.WriteLine("Q");
-	}
-
-	/*
-	 * this method don't use RDotNet, then has to call call_graph.R, who will call graph.R
-	 * and has to write a Roptions.txt file
-	 */
-	public static bool RunEncoderGraphNoRDotNet(string title, EncoderStruct es, bool neuromuscularProfileDo, bool translate) 
-	{
-		CancelRScript = false;
-
-		ProcessStartInfo pinfo;
-	        Process p;
-		//If output file is not given, R will try to write in the running folder
-		//in which we may haven't got permissions
-	
-		string pBin="";
-		pinfo = new ProcessStartInfo();
-
-		pBin="Rscript";
-		if (UtilAll.IsWindows()) {
-			//on Windows we need the \"str\" to call without problems in path with spaces
-			pBin = "\"" + System.IO.Path.Combine(Util.GetPrefixDir(), "bin" + Path.DirectorySeparatorChar + "Rscript.exe") + "\"";
-			LogB.Information("pBin:", pBin);
-		}
-		
-
-		string scriptOptions = PrepareEncoderGraphOptions(title, es, neuromuscularProfileDo, translate).ToString();
-
-		string optionsFile = Path.GetTempPath() + "Roptions.txt";
-		TextWriter writer = File.CreateText(optionsFile);
-		writer.Write(scriptOptions);
-		writer.Flush();
-		writer.Close();
-		((IDisposable)writer).Dispose();
-		
-		if (UtilAll.IsWindows()) {
-			//On win32 R understands backlash as an escape character and 
-			//a file path uses Unix-like path separator '/'		
-			optionsFile = optionsFile.Replace("\\","/");
-		}
-		
-		//on Windows we need the \"str\" to call without problems in path with spaces
-		pinfo.Arguments = "\"" + getEncoderScriptCallGraph() + "\" " + optionsFile;
-	
-		LogB.Information("Arguments:", pinfo.Arguments);
-		LogB.Information("--- 1 --- " + optionsFile.ToString() + " ---");
-		LogB.Information("--- 2 --- " + scriptOptions + " ---");
-		LogB.Information("--- 3 --- " + pinfo.Arguments.ToString() + " ---");
-		
-		string outputFileCheck = "";
-		string outputFileCheck2 = "";
-		
-		//Wait until this to update encoder gui (if don't wait then treeview will be outdated)
-		//exportCSV is the only one that doesn't have graph. all the rest Analysis have graph and data
-		if(es.Ep.Analysis == "exportCSV")
-			outputFileCheck = es.OutputData1; 
-		else {
-			//outputFileCheck = es.OutputGraph;
-			//
-			//OutputData1 because since Chronojump 1.3.6, 
-			//encoder analyze has a treeview that can show the curves
-			//when a graph analysis is done, curves file has to be written
-			outputFileCheck = es.OutputData1;
-		        //check also the otuput graph
-			outputFileCheck2 = es.OutputGraph; 
-		}
-
-		pinfo.FileName=pBin;
-
-		pinfo.CreateNoWindow = true;
-		pinfo.UseShellExecute = false;
-		pinfo.RedirectStandardError = true;
-		pinfo.RedirectStandardOutput = true; 
-
-
-		//delete output file check(s)
-		LogB.Information("Deleting... " + outputFileCheck);
-		if (File.Exists(outputFileCheck))
-			File.Delete(outputFileCheck);
-
-		if(outputFileCheck2 != "") {
-			LogB.Information("Deleting... " + outputFileCheck2);
-			if (File.Exists(outputFileCheck2))
-				File.Delete(outputFileCheck2);
-		}
-			
-		//delete 1RM data if exists
-		if (File.Exists(es.SpecialData))
-			File.Delete(es.SpecialData);
-
-		//try catch crash sometimes when used in conjunction with RDotNet
-		//now RDotNet is not used
-		try {	
-			p = new Process();
-			p.StartInfo = pinfo;
-			p.Start();
-
-			LogB.Information(p.StandardOutput.ReadToEnd());
-			LogB.Warning(p.StandardError.ReadToEnd());
-
-			p.WaitForExit();
-
-			if(outputFileCheck2 == "")
-				while ( ! ( File.Exists(outputFileCheck) || CancelRScript) );
-			else
-				while ( ! ( (File.Exists(outputFileCheck) && File.Exists(outputFileCheck2)) || CancelRScript ) );
-		} catch {
-			return false;
-		}
-
-		return true;
-	}
-	
 	//Inertia Momentum
-	public static void RunEncoderCalculeIM(double weight, double length) 
+	//TODO: make this work with encoderRProc
+	public static void RunEncoderCalculeIM(double weight, double length, EncoderRProcAnalyze encoderRProcAnalyze) 
 	{
-		CancelRScript = false;
+		encoderRProcAnalyze.CancelRScript = false;
 
 		ProcessStartInfo pinfo;
 	        Process p;
@@ -726,7 +417,7 @@ public class UtilEncoder
 
 			p.WaitForExit();
 
-			while ( ! ( File.Exists(outputFileCheck) || CancelRScript) );
+			while ( ! ( File.Exists(outputFileCheck) || encoderRProcAnalyze.CancelRScript) );
 		} catch {
 		}
 	}
@@ -745,6 +436,10 @@ public class UtilEncoder
 	 * valuesForNewLine is 25 means every 25 values there will be a newLine. 0 will mean no newlines
 	 */
 	
+	/*
+	 * valuesForNewLine means how many values want in a line. If it's >= []curve, then there will be only one line
+	 * there's a test of this function at testing-stuff/compressCurve.cs
+	 */
 	public static string CompressData(double [] curve, int valuesForNewLine)
 	{
 		string compressed = "";
@@ -1032,104 +727,46 @@ public class UtilEncoder
 					Constants.EncoderConfigurationNames.ROTARYFRICTIONSIDE));
 			list.Add(new EncoderConfiguration(
 					Constants.EncoderConfigurationNames.ROTARYFRICTIONAXIS));
+			list.Add(new EncoderConfiguration(
+					Constants.EncoderConfigurationNames.WEIGHTEDMOVPULLEYROTARYFRICTION));
 			list.Add(new EncoderConfiguration(
 					Constants.EncoderConfigurationNames.ROTARYFRICTIONSIDEINERTIAL));
 			list.Add(new EncoderConfiguration(
 					Constants.EncoderConfigurationNames.ROTARYFRICTIONAXISINERTIAL));
 			list.Add(new EncoderConfiguration(
-					Constants.EncoderConfigurationNames.WEIGHTEDMOVPULLEYROTARYFRICTION));
+					Constants.EncoderConfigurationNames.ROTARYFRICTIONSIDEINERTIALLATERAL));
+			list.Add(new EncoderConfiguration(
+					Constants.EncoderConfigurationNames.ROTARYFRICTIONAXISINERTIALLATERAL));
+			list.Add(new EncoderConfiguration(
+					Constants.EncoderConfigurationNames.ROTARYFRICTIONSIDEINERTIALMOVPULLEY));
+			list.Add(new EncoderConfiguration(
+					Constants.EncoderConfigurationNames.ROTARYFRICTIONAXISINERTIALMOVPULLEY));
 		} else if(encoderType == Constants.EncoderType.ROTARYAXIS) {
 			list.Add(new EncoderConfiguration(
 					Constants.EncoderConfigurationNames.ROTARYAXIS));
+			list.Add(new EncoderConfiguration(
+					Constants.EncoderConfigurationNames.WEIGHTEDMOVPULLEYROTARYAXIS));
 			list.Add(new EncoderConfiguration(
 					Constants.EncoderConfigurationNames.ROTARYAXISINERTIAL));
 			list.Add(new EncoderConfiguration(
-					Constants.EncoderConfigurationNames.WEIGHTEDMOVPULLEYROTARYAXIS));
+					Constants.EncoderConfigurationNames.ROTARYAXISINERTIALLATERAL));
+			list.Add(new EncoderConfiguration(
+					Constants.EncoderConfigurationNames.ROTARYAXISINERTIALMOVPULLEY));
 		}
 		return list;
 	}
 
-	/* -------- EncoderConfiguration, kinematics and Dynamics ---- 
-	 *
-	 *  		this is the same than graph.R
-	 * -------------------------------------------------------- */
+	public static int CalculeInertiaTotal (EncoderConfiguration econf) {
+		//LogB.Debug(econf.ToString(":",false,false));
+		int n = econf.extraWeightN;
+		double weightInKg = econf.extraWeightGrams / 1000.0;
+		double length = econf.extraWeightLength;
 
-	/*
-	 * in signals and curves, need to do conversions (invert, inertiaMomentum, diameter)
-	 * we use 'data' variable because can be position or displacement
-	 */
+		//IM of all the weights = n * (weight * length^2) Kg*cm^2
+		int im_weights = Convert.ToInt32(n * ( weightInKg * Math.Pow(length,2) ));
 
-	public static double GetDisplacement(int byteReaded, EncoderConfiguration ec) {
-		/* no change:
-		 * WEIGHTEDMOVPULLEYLINEARONPERSON1, WEIGHTEDMOVPULLEYLINEARONPERSON1INV,
-		 * WEIGHTEDMOVPULLEYLINEARONPERSON2, WEIGHTEDMOVPULLEYLINEARONPERSON2INV,
-		 * LINEARONPLANE, LINEARONPLANEWEIGHTDIFFANGLE, ROTARYFRICTIONSIDE, WEIGHTEDMOVPULLEYROTARYFRICTION
-		 */
-
-		double data = byteReaded;
-		if(
-				ec.name == Constants.EncoderConfigurationNames.LINEARINVERTED ||
-				ec.name == Constants.EncoderConfigurationNames.WEIGHTEDMOVPULLEYLINEARONPERSON1INV ||
-				ec.name == Constants.EncoderConfigurationNames.WEIGHTEDMOVPULLEYLINEARONPERSON2INV ) {
-			data *= -1;
-		} else if(ec.name == Constants.EncoderConfigurationNames.WEIGHTEDMOVPULLEYONLINEARENCODER) {
-			//default is: gearedDown = 2. Future maybe this will be a parameter
-			data *= 2;
-		} else if(ec.name == Constants.EncoderConfigurationNames.ROTARYFRICTIONAXIS) {
-			data = data * ec.D / ec.d;
-		} else if(
-				ec.name == Constants.EncoderConfigurationNames.ROTARYAXIS || 
-				ec.name == Constants.EncoderConfigurationNames.WEIGHTEDMOVPULLEYROTARYAXIS) 
-		{
-			int ticksRotaryEncoder = 200; //our rotary axis encoder send 200 ticks by turn
-			//diameter m -> mm
-			data = ( data / ticksRotaryEncoder ) * 2 * Math.PI * ( ec.d * 1000 / 2 );
-		}
-		return data;
+		return econf.inertiaMachine + im_weights;
 	}
-
-	//gearedDown is positive, normally 2
-	private static double getMass(double mass, int gearedDown, int angle) {
-		if(mass == 0)
-			return 0;
-
-		return ( ( mass / gearedDown ) * Math.Sin( angle * Math.PI / 180 ) );
-	}
-
-	private static double getMassBodyByExercise(double massBody, int exercisePercentBodyWeight) {
-		if(massBody == 0 || exercisePercentBodyWeight == 0)
-			return 0;
-
-		return (massBody * exercisePercentBodyWeight / 100.0);
-	}
-
-	public static double GetMassByEncoderConfiguration(
-			EncoderConfiguration ec, double massBody, double massExtra, int exercisePercentBodyWeight)
-	{
-		massBody = getMassBodyByExercise(massBody, exercisePercentBodyWeight);
-
-		if(
-			ec.name == Constants.EncoderConfigurationNames.WEIGHTEDMOVPULLEYLINEARONPERSON1 ||
-			ec.name == Constants.EncoderConfigurationNames.WEIGHTEDMOVPULLEYLINEARONPERSON1INV ||
-			ec.name == Constants.EncoderConfigurationNames.WEIGHTEDMOVPULLEYLINEARONPERSON2 ||
-			ec.name == Constants.EncoderConfigurationNames.WEIGHTEDMOVPULLEYLINEARONPERSON2INV ||
-			ec.name == Constants.EncoderConfigurationNames.WEIGHTEDMOVPULLEYROTARYFRICTION ||
-			ec.name == Constants.EncoderConfigurationNames.WEIGHTEDMOVPULLEYROTARYAXIS 
-		  ) {
-			massExtra = getMass(massExtra, ec.gearedDown, ec.anglePush);
-		} 
-		else if(ec.name == Constants.EncoderConfigurationNames.LINEARONPLANE) {
-			massBody = getMass(massBody, ec.gearedDown, ec.anglePush);
-			massExtra = getMass(massExtra, ec.gearedDown, ec.anglePush);
-		}
-		else if(ec.name == Constants.EncoderConfigurationNames.LINEARONPLANEWEIGHTDIFFANGLE) {
-			massBody = getMass(massBody, ec.gearedDown, ec.anglePush);
-			massExtra = getMass(massExtra, ec.gearedDown, ec.angleWeight);
-		}
-
-		return (massBody + massExtra);
-	}
-
-	/* ----end of EncoderConfiguration, kinematics and Dynamics ---- */ 
+		
 
 }
